@@ -14,6 +14,12 @@
 # Copyright Buildbot Team Members
 
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+from typing import Any
+from typing import Callable
+
 from buildbot.config.checks import check_markdown_support
 from buildbot.config.checks import check_param_length
 from buildbot.config.checks import check_param_str_none
@@ -23,37 +29,42 @@ from buildbot.util import bytes2unicode
 from buildbot.util import config as util_config
 from buildbot.util import safeTranslate
 
+if TYPE_CHECKING:
+    from buildbot.process.build import Build
+
+
 RESERVED_UNDERSCORE_NAMES = ["__Janitor"]
 
 
 class BuilderConfig(util_config.ConfiguredMixin):
     def __init__(
         self,
-        name=None,
-        workername=None,
-        workernames=None,
-        builddir=None,
-        workerbuilddir=None,
-        factory=None,
-        tags=None,
-        nextWorker=None,
-        nextBuild=None,
-        locks=None,
-        env=None,
-        properties=None,
-        collapseRequests=None,
-        description=None,
-        description_format=None,
-        canStartBuild=None,
-        defaultProperties=None,
-        project=None,
-    ):
+        name: str | bytes | None = None,
+        workername: str | None = None,
+        workernames: list[str] | str | None = None,
+        builddir: str | None = None,
+        workerbuilddir: str | None = None,
+        factory: Any = None,
+        tags: list[str] | None = None,
+        nextWorker: Callable | None = None,
+        nextBuild: Callable | None = None,
+        locks: list | None = None,
+        env: dict | None = None,
+        properties: dict | None = None,
+        collapseRequests: bool | Callable | None = None,
+        description: str | None = None,
+        description_format: str | None = None,
+        canStartBuild: Callable | None = None,
+        defaultProperties: dict | None = None,
+        project: str | None = None,
+        do_build_if: Callable[[Build], bool] | None = None,
+    ) -> None:
         # name is required, and can't start with '_'
         if not name or type(name) not in (bytes, str):
             error("builder's name is required")
             name = '<unknown>'
         elif name[0] == '_' and name not in RESERVED_UNDERSCORE_NAMES:
-            error(f"builder names must not start with an underscore: '{name}'")
+            error(f"builder names must not start with an underscore: {name!r}")
         try:
             self.name = bytes2unicode(name, encoding="ascii")
         except UnicodeDecodeError:
@@ -66,11 +77,11 @@ class BuilderConfig(util_config.ConfiguredMixin):
 
         # factory is required
         if factory is None:
-            error(f"builder '{name}' has no factory")
+            error(f"builder {self.name!r}: has no factory")
         from buildbot.process.factory import BuildFactory
 
         if factory is not None and not isinstance(factory, BuildFactory):
-            error(f"builder '{name}'s factory is not a BuildFactory instance")
+            error(f"builder {self.name!r}: factory is not a BuildFactory instance")
         self.factory = factory
 
         # workernames can be a single worker name or a list, and should also
@@ -79,16 +90,18 @@ class BuilderConfig(util_config.ConfiguredMixin):
             workernames = [workernames]
         if workernames:
             if not isinstance(workernames, list):
-                error(f"builder '{name}': workernames must be a list or a string")
+                error(f"builder {self.name!r}: workernames must be a list or a string")
         else:
             workernames = []
 
         if workername:
             if not isinstance(workername, str):
-                error(f"builder '{name}': workername must be a string but it is {workername!r}")
+                error(
+                    f"builder {self.name!r}: workername must be a string but it is {workername!r}"
+                )
             workernames = [*workernames, workername]
         if not workernames:
-            error(f"builder '{name}': at least one workername is required")
+            error(f"builder {self.name!r}: at least one workername is required")
 
         self.workernames = workernames
 
@@ -106,14 +119,14 @@ class BuilderConfig(util_config.ConfiguredMixin):
         # remainder are optional
         if tags:
             if not isinstance(tags, list):
-                error(f"builder '{name}': tags must be a list")
+                error(f"builder {self.name!r}: tags must be a list")
             bad_tags = any(tag for tag in tags if not isinstance(tag, str))
             if bad_tags:
-                error(f"builder '{name}': tags list contains something that is not a string")
+                error(f"builder {self.name!r}: tags list contains something that is not a string")
 
             if len(tags) != len(set(tags)):
                 dupes = " ".join({x for x in tags if tags.count(x) > 1})
-                error(f"builder '{name}': tags list contains duplicate tags: {dupes}")
+                error(f"builder {self.name!r}: tags list contains duplicate tags: {dupes}")
         else:
             tags = []
 
@@ -164,7 +177,12 @@ class BuilderConfig(util_config.ConfiguredMixin):
             error("builder description format must be None or \"markdown\"")
             self.description_format = None
 
-    def getConfigDict(self):
+        if do_build_if is not None:
+            self.do_build_if = do_build_if
+        else:
+            self.do_build_if = lambda x: True
+
+    def getConfigDict(self) -> dict:
         # note: this method will disappear eventually - put your smarts in the
         # constructor!
         rv = {
