@@ -45,10 +45,10 @@ def _db2data(model: MasterModel):
 
 class MasterEndpoint(base.Endpoint):
     kind = base.EndpointKind.SINGLE
-    pathPatterns = """
-        /masters/n:masterid
-        /builders/n:builderid/masters/n:masterid
-    """
+    pathPatterns = [
+        "/masters/n:masterid",
+        "/builders/n:builderid/masters/n:masterid",
+    ]
 
     @defer.inlineCallbacks
     def get(self, resultSpec, kwargs):
@@ -64,10 +64,10 @@ class MasterEndpoint(base.Endpoint):
 
 class MastersEndpoint(base.Endpoint):
     kind = base.EndpointKind.COLLECTION
-    pathPatterns = """
-        /masters
-        /builders/n:builderid/masters
-    """
+    pathPatterns = [
+        "/masters",
+        "/builders/n:builderid/masters",
+    ]
     rootLinkName = 'masters'
 
     @defer.inlineCallbacks
@@ -87,11 +87,9 @@ class Master(base.ResourceType):
     name = "master"
     plural = "masters"
     endpoints = [MasterEndpoint, MastersEndpoint]
-    eventPathPatterns = """
-        /masters/:masterid
-    """
-    keyField = "masterid"
-    subresources = ["Builder"]
+    eventPathPatterns = [
+        "/masters/:masterid",
+    ]
 
     class EntityType(types.Entity):
         masterid = types.Integer()
@@ -99,18 +97,18 @@ class Master(base.ResourceType):
         active = types.Boolean()
         last_active = types.DateTime()
 
-    entityType = EntityType(name, 'Master')
+    entityType = EntityType(name)
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def masterActive(self, name, masterid):
+    def masterActive(self, name: str, masterid: int):
         activated = yield self.master.db.masters.setMasterState(masterid=masterid, active=True)
         if activated:
             self.produceEvent({"masterid": masterid, "name": name, "active": True}, 'started')
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def expireMasters(self, forceHouseKeeping=False):
+    def expireMasters(self, forceHouseKeeping: bool = False):
         too_old = epoch2datetime(self.master.reactor.seconds() - 60 * EXPIRE_MINUTES)
         masters = yield self.master.db.masters.getMasters()
         for m in masters:
@@ -126,7 +124,7 @@ class Master(base.ResourceType):
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def masterStopped(self, name, masterid):
+    def masterStopped(self, name: str, masterid: int):
         deactivated = yield self.master.db.masters.setMasterState(masterid=masterid, active=False)
         if deactivated:
             yield self._masterDeactivated(masterid, name)
