@@ -13,19 +13,27 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
+
 import json
+from typing import TYPE_CHECKING
+from typing import Any
 
 from twisted.internet import defer
 
 from buildbot.data import base
 from buildbot.data import types
 
+if TYPE_CHECKING:
+    from buildbot.interfaces import IProperties
+    from buildbot.util.twisted import InlineCallbacksType
+
 
 class BuildsetPropertiesEndpoint(base.Endpoint):
     kind = base.EndpointKind.SINGLE
-    pathPatterns = """
-        /buildsets/n:bsid/properties
-    """
+    pathPatterns = [
+        "/buildsets/n:bsid/properties",
+    ]
 
     def get(self, resultSpec, kwargs):
         return self.master.db.buildsets.getBuildsetProperties(kwargs['bsid'])
@@ -33,10 +41,10 @@ class BuildsetPropertiesEndpoint(base.Endpoint):
 
 class BuildPropertiesEndpoint(base.Endpoint):
     kind = base.EndpointKind.SINGLE
-    pathPatterns = """
-        /builders/n:builderid/builds/n:build_number/properties
-        /builds/n:buildid/properties
-    """
+    pathPatterns = [
+        "/builders/n:builderid/builds/n:build_number/properties",
+        "/builds/n:buildid/properties",
+    ]
 
     @defer.inlineCallbacks
     def get(self, resultSpec, kwargs):
@@ -48,11 +56,11 @@ class BuildPropertiesEndpoint(base.Endpoint):
 
 class PropertiesListEndpoint(base.Endpoint):
     kind = base.EndpointKind.COLLECTION
-    pathPatterns = """
-        /builds/n:buildid/property_list
-        /buildsets/n:bsid/properties_list
-        /changes/n:changeid/properties_list
-    """
+    pathPatterns = [
+        "/builds/n:buildid/property_list",
+        "/buildsets/n:bsid/properties_list",
+        "/changes/n:changeid/properties_list",
+    ]
     buildFieldMapping = {
         "name": "build_properties.name",
         "source": "build_properties.source",
@@ -93,16 +101,14 @@ class Property(base.ResourceType):
     name = "_property"
     plural = "_properties"
     endpoints = [PropertiesListEndpoint]
-    keyField = "name"
 
-    entityType = types.PropertyEntityType(name, 'Property')
+    entityType = types.PropertyEntityType(name)
 
 
 class Properties(base.ResourceType):
     name = "property"
     plural = "properties"
     endpoints = [BuildsetPropertiesEndpoint, BuildPropertiesEndpoint]
-    keyField = "name"
 
     entityType = types.SourcedProperties()
 
@@ -118,12 +124,14 @@ class Properties(base.ResourceType):
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def setBuildProperties(self, buildid, properties):
+    def setBuildProperties(
+        self, buildid: int, properties: IProperties
+    ) -> InlineCallbacksType[None]:
         to_update = {}
         oldproperties = yield self.master.data.get(('builds', str(buildid), "properties"))
-        properties = properties.getProperties()
-        properties = yield properties.render(properties.asDict())
-        for k, v in properties.items():
+        properties_real = properties.getProperties()
+        properties_dict = yield properties_real.render(properties_real.asDict())
+        for k, v in properties_dict.items():
             if k in oldproperties and oldproperties[k] == v:
                 continue
             to_update[k] = v
@@ -135,7 +143,9 @@ class Properties(base.ResourceType):
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def setBuildProperty(self, buildid, name, value, source):
+    def setBuildProperty(
+        self, buildid: int, name: str, value: Any, source: str
+    ) -> InlineCallbacksType[None]:
         res = yield self.master.db.builds.setBuildProperty(buildid, name, value, source)
         yield self.generateUpdateEvent(buildid, {"name": (value, source)})
         return res
