@@ -13,14 +13,15 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
 
+from twisted.internet import defer
 from twisted.python.reflect import namedObject
 
 from buildbot.util import service
 
 
 class MQConnector(service.ReconfigurableServiceMixin, service.AsyncMultiService):
-
     classes = {
         'simple': {
             'class': "buildbot.mq.simple.SimpleMQ",
@@ -31,13 +32,14 @@ class MQConnector(service.ReconfigurableServiceMixin, service.AsyncMultiService)
             'keys': set(["router_url", "realm", "wamp_debug_level"]),
         },
     }
-    name = 'mq'
+    name: str | None = 'mq'  # type: ignore[assignment]
 
     def __init__(self):
-        service.AsyncMultiService.__init__(self)
+        super().__init__()
         self.impl = None  # set in setup
         self.impl_type = None  # set in setup
 
+    @defer.inlineCallbacks
     def setup(self):
         assert not self.impl
 
@@ -50,7 +52,7 @@ class MQConnector(service.ReconfigurableServiceMixin, service.AsyncMultiService)
         self.impl = cls()
 
         # set up the impl as a child service
-        self.impl.setServiceParent(self)
+        yield self.impl.setServiceParent(self)
 
         # configure it (early)
         self.impl.reconfigServiceWithBuildbotConfig(self.master.config)
@@ -64,8 +66,7 @@ class MQConnector(service.ReconfigurableServiceMixin, service.AsyncMultiService)
         # double-check -- the master ensures this in config checks
         assert self.impl_type == new_config.mq['type']
 
-        return service.ReconfigurableServiceMixin.reconfigServiceWithBuildbotConfig(self,
-                                                                                    new_config)
+        return super().reconfigServiceWithBuildbotConfig(new_config)
 
     def produce(self, routing_key, data):
         # will be patched after configuration to point to the running
