@@ -14,8 +14,7 @@
 # Copyright Buildbot Team Members
 
 
-"""Base classes handy for use with PB clients.
-"""
+"""Base classes handy for use with PB clients."""
 
 from twisted.internet import protocol
 from twisted.python import log
@@ -26,7 +25,6 @@ from buildbot.util import bytes2unicode
 
 
 class NewCredPerspective(pb.Avatar):
-
     def attached(self, mind):
         return self
 
@@ -34,9 +32,7 @@ class NewCredPerspective(pb.Avatar):
         pass
 
 
-class ReconnectingPBClientFactory(PBClientFactory,
-                                  protocol.ReconnectingClientFactory):
-
+class ReconnectingPBClientFactory(PBClientFactory, protocol.ReconnectingClientFactory):
     """Reconnecting client factory for PB brokers.
 
     Like PBClientFactory, but if the connection fails or is lost, the factory
@@ -97,21 +93,19 @@ class ReconnectingPBClientFactory(PBClientFactory,
     def getPerspective(self, *args):
         raise RuntimeError("getPerspective is one-shot: use startGettingPerspective instead")
 
-    def startGettingPerspective(self, username, password, serviceName,
-                                perspectiveName=None, client=None):
+    def startGettingPerspective(
+        self, username, password, serviceName, perspectiveName=None, client=None
+    ):
         self._doingGetPerspective = True
         if perspectiveName is None:
             perspectiveName = username
-        self._oldcredArgs = (username, password, serviceName,
-                             perspectiveName, client)
+        self._oldcredArgs = (username, password, serviceName, perspectiveName, client)
 
     def doGetPerspective(self, root):
         # oldcred getPerspective()
-        (username, password,
-         serviceName, perspectiveName, client) = self._oldcredArgs
+        (username, password, serviceName, perspectiveName, client) = self._oldcredArgs
         d = self._cbAuthIdentity(root, username, password)
-        d.addCallback(self._cbGetPerspective,
-                      serviceName, perspectiveName, client)
+        d.addCallback(self._cbGetPerspective, serviceName, perspectiveName, client)
         d.addCallbacks(self.gotPerspective, self.failedToGetPerspective)
 
     # newcred methods
@@ -125,8 +119,9 @@ class ReconnectingPBClientFactory(PBClientFactory,
 
     def doLogin(self, root):
         # newcred login()
-        d = self._cbSendUsername(root, self._credentials.username,
-                                 self._credentials.password, self._client)
+        d = self._cbSendUsername(
+            root, self._credentials.username, self._credentials.password, self._client
+        )
         d.addCallbacks(self.gotPerspective, self.failedToGetPerspective)
 
     # methods to override
