@@ -37,7 +37,6 @@ class Log:
         self.subscriptions = {}
         self._finishing = False
         self.finished = False
-        self.finishWaiters = []
         self._had_errors = False
         self.lock = defer.DeferredLock()
         self.decoder = decoder
@@ -64,12 +63,12 @@ class Log:
         decoder = Log._decoderFromString(logEncoding)
         return subcls(master, name, type, logid, decoder)
 
-    def getName(self):
+    def getName(self) -> str:
         return self.name
 
     # subscriptions
 
-    def subscribe(self, callback):
+    def subscribe(self, callback) -> util.subscription.Subscription:
         return self.subPoint.subscribe(callback)
 
     # adding lines
@@ -84,20 +83,12 @@ class Log:
 
     # completion
 
-    def isFinished(self):
-        return self.finished
-
-    def waitUntilFinished(self):
-        d = defer.Deferred()
-        if self.finished:
-            d.succeed(None)
-        else:
-            self.finishWaiters.append(d)
-        return d
-
-    def had_errors(self):
+    def had_errors(self) -> bool:
         return self._had_errors
 
+    def flush(self):
+        return defer.succeed(None)
+
     @defer.inlineCallbacks
     def finish(self):
         assert not self._finishing, "Did you maybe forget to yield the method?"
@@ -114,10 +105,6 @@ class Log:
 
         yield self.subPoint.waitForDeliveriesToFinish()
 
-        # notify those waiting for finish
-        for d in self.finishWaiters:
-            d.callback(None)
-
         self._had_errors = len(self.subPoint.pop_exceptions()) > 0
 
         # start a compressLog call but don't make our caller wait for
@@ -134,7 +121,7 @@ class PlainLog(Log):
 
         self.lbf = lineboundaries.LineBoundaryFinder()
 
-    def addContent(self, text):
+    def addContent(self, text: str | bytes):
         if not isinstance(text, str):
             text = self.decoder(text)
         # add some text in the log's default stream
@@ -145,11 +132,15 @@ class PlainLog(Log):
         return self.addRawLines(lines)
 
     @defer.inlineCallbacks
-    def finish(self):
+    def flush(self):
         lines = self.lbf.flush()
         if lines is not None:
             self.subPoint.deliver(None, lines)
             yield self.addRawLines(lines)
+
+    @defer.inlineCallbacks
+    def finish(self):
+        yield self.flush()
         yield super().finish()
 
 
@@ -225,12 +216,16 @@ class StreamLog(Log):
             text = self.decoder(text)
         return self._on_whole_lines('h', text)
 
-    @defer.inlineCallbacks
-    def finish(self):
+    def flush(self):
         for stream, lbf in self.lbfs.items():
             lines = lbf.flush()
             if lines is not None:
                 self._on_whole_lines(stream, lines)
+        return defer.succeed(None)
+
+    @defer.inlineCallbacks
+    def finish(self):
+        yield self.flush()
         yield super().finish()
 
 
