@@ -39,16 +39,19 @@ import os
 import sys
 from collections import defaultdict
 from collections import deque
+from typing import TYPE_CHECKING
 
 from twisted.application import service
 from twisted.internet import reactor
-from twisted.internet.base import ReactorBase
 from twisted.internet.task import LoopingCall
 from twisted.python import log
 
 from buildbot import util
 from buildbot.util import service as util_service
 
+if TYPE_CHECKING:
+    from twisted.internet.base import ReactorBase
+
 # Make use of the resource module if we can
 try:
     import resource
