@@ -20,12 +20,11 @@ from twisted.internet import defer
 from buildbot.util import service as util_service
 
 
-class UserManagerManager(util_service.ReconfigurableServiceMixin,
-                         service.MultiService):
+class UserManagerManager(util_service.ReconfigurableServiceMixin, service.MultiService):
     # this class manages a fleet of user managers; hence the name..
 
     def __init__(self, master):
-        service.MultiService.__init__(self)
+        super().__init__()
         self.setName('user_manager_manager')
         self.master = master
 
@@ -36,11 +35,10 @@ class UserManagerManager(util_service.ReconfigurableServiceMixin,
 
         # pylint: disable=cell-var-from-loop
         for mgr in list(self):
-            yield defer.maybeDeferred(mgr.disownServiceParent)
+            yield mgr.disownServiceParent()
 
         for mgr in new_config.user_managers:
             yield mgr.setServiceParent(self)
 
         # reconfig any newly-added change sources, as well as existing
-        yield util_service.ReconfigurableServiceMixin.reconfigServiceWithBuildbotConfig(self,
-                                                                                        new_config)
+        yield super().reconfigServiceWithBuildbotConfig(new_config)
