@@ -13,6 +13,7 @@
 #
 # Copyright Buildbot Team Members
 
+from typing import Any
 from typing import ClassVar
 from typing import Sequence
 
@@ -27,13 +28,28 @@ from buildbot.util import debounce
 
 
 @implementer(ITriggerableScheduler)
-class Triggerable(base.BaseScheduler):
-    compare_attrs: ClassVar[Sequence[str]] = (*base.BaseScheduler.compare_attrs, 'reason')
+class Triggerable(base.ReconfigurableBaseScheduler):
+    compare_attrs: ClassVar[Sequence[str]] = (
+        *base.ReconfigurableBaseScheduler.compare_attrs,
+        'reason',
+    )
 
-    def __init__(self, name, builderNames, reason=None, **kwargs):
-        super().__init__(name, builderNames, **kwargs)
+    def __init__(self, name, builderNames, *args, **kwargs):
+        super().__init__(*args, name=name, builderNames=builderNames, **kwargs)
         self._waiters = {}
         self._buildset_complete_consumer = None
+
+    def checkConfig(self, builderNames, reason=None, **kwargs: Any):  # type: ignore[override]
+        super().checkConfig(builderNames=builderNames, **kwargs)
+
+    @defer.inlineCallbacks
+    def reconfigService(  # type: ignore[override]
+        self,
+        builderNames,
+        reason=None,
+        **kwargs: Any,
+    ):
+        yield super().reconfigService(builderNames=builderNames, **kwargs)
         self.reason = reason
 
     def trigger(
