@@ -16,6 +16,7 @@
 import base64
 import json
 import os
+from typing import Any
 from typing import ClassVar
 from typing import Sequence
 
@@ -31,9 +32,10 @@ from buildbot.util import bytes2unicode
 from buildbot.util import netstrings
 from buildbot.util import unicode2bytes
 from buildbot.util.maildir import MaildirService
+from buildbot.util.service import IndependentAsyncMultiService
 
 
-class TryBase(base.BaseScheduler):
+class TryBase(base.ReconfigurableBaseScheduler):
     def filterBuilderList(self, builderNames):
         """
         Make sure that C{builderNames} is a subset of the configured
@@ -82,19 +84,40 @@ class Try_Jobdir(TryBase):
     compare_attrs: ClassVar[Sequence[str]] = ('jobdir',)
 
     def __init__(self, name, builderNames, jobdir, **kwargs):
-        super().__init__(name, builderNames, **kwargs)
-        self.jobdir = jobdir
+        super().__init__(name=name, builderNames=builderNames, jobdir=jobdir, **kwargs)
         self.watcher = JobdirService(scheduler=self)
+        self._watcher_parent = IndependentAsyncMultiService()
+        self.watcher.setServiceParent(self._watcher_parent)
 
-    # TryBase used to be a MultiService and managed the JobdirService via a parent/child
-    # relationship. We stub out the addService/removeService and just keep track of
-    # JobdirService as self.watcher. We'll refactor these things later and remove
-    # the need for this.
-    def addService(self, child):
-        pass
+    def checkConfig(self, builderNames, jobdir, **kwargs: Any):  # type: ignore[override]
+        super().checkConfig(builderNames=builderNames, **kwargs)
 
-    def removeService(self, child):
-        pass
+    @defer.inlineCallbacks
+    def reconfigService(  # type: ignore[override]
+        self,
+        builderNames,
+        jobdir,
+        **kwargs: Any,
+    ):
+        yield super().reconfigService(builderNames=builderNames, **kwargs)
+        self.jobdir = jobdir
+        self._watcher_parent.set_master(self.master)
+
+        if self.active:
+            self._watcher_parent.stopService()
+            self._start_watcher()
+
+    def _start_watcher(self):
+        # set the watcher's basedir now that we have a master
+        jobdir = os.path.join(self.master.basedir, self.jobdir)
+        self.watcher.setBasedir(jobdir)
+        for subdir in "cur new tmp".split():
+            if not os.path.exists(os.path.join(jobdir, subdir)):
+                os.makedirs(os.path.join(jobdir, subdir))
+
+        # bridge the activate/deactivate to a startService/stopService on the
+        # child service
+        self._watcher_parent.startService()
 
     # activation handlers
 
@@ -105,16 +128,7 @@ class Try_Jobdir(TryBase):
         if not self.enabled:
             return
 
-        # set the watcher's basedir now that we have a master
-        jobdir = os.path.join(self.master.basedir, self.jobdir)
-        self.watcher.setBasedir(jobdir)
-        for subdir in "cur new tmp".split():
-            if not os.path.exists(os.path.join(jobdir, subdir)):
-                os.mkdir(os.path.join(jobdir, subdir))
-
-        # bridge the activate/deactivate to a startService/stopService on the
-        # child service
-        self.watcher.startService()
+        self._start_watcher()
 
     @defer.inlineCallbacks
     def deactivate(self):
@@ -123,9 +137,7 @@ class Try_Jobdir(TryBase):
         if not self.enabled:
             return
 
-        # bridge the activate/deactivate to a startService/stopService on the
-        # child service
-        self.watcher.stopService()
+        self._watcher_parent.stopService()
 
     def parseJob(self, f):
         # jobfiles are serialized build requests. Each is a list of
@@ -482,18 +494,33 @@ class Try_Userpass(TryBase):
     )
 
     def __init__(self, name, builderNames, port, userpass, **kwargs):
-        super().__init__(name, builderNames, **kwargs)
+        super().__init__(
+            name=name, builderNames=builderNames, port=port, userpass=userpass, **kwargs
+        )
+        self.registrations = []
+
+    def checkConfig(self, builderNames, port, userpass, **kwargs: Any):  # type: ignore[override]
+        super().checkConfig(builderNames=builderNames, **kwargs)
+
+    @defer.inlineCallbacks
+    def reconfigService(  # type: ignore[override]
+        self,
+        builderNames,
+        port,
+        userpass,
+        **kwargs: Any,
+    ):
+        yield super().reconfigService(builderNames=builderNames, **kwargs)
         self.port = port
         self.userpass = userpass
         self.registrations = []
 
+        if self.active:
+            yield self._destroy_pb()
+            yield self._create_pb()
+
     @defer.inlineCallbacks
-    def activate(self):
-        yield super().activate()
-
-        if not self.enabled:
-            return
-
+    def _create_pb(self):
         # register each user/passwd with the pbmanager
         def factory(mind, username):
             return Try_Userpass_Perspective(self, username)
@@ -502,6 +529,22 @@ class Try_Userpass(TryBase):
             reg = yield self.master.pbmanager.register(self.port, user, passwd, factory)
             self.registrations.append(reg)
 
+    @defer.inlineCallbacks
+    def _destroy_pb(self):
+        yield defer.gatherResults(
+            [reg.unregister() for reg in self.registrations], consumeErrors=True
+        )
+        self.registrations = []
+
+    @defer.inlineCallbacks
+    def activate(self):
+        yield super().activate()
+
+        if not self.enabled:
+            return
+
+        yield self._create_pb()
+
     @defer.inlineCallbacks
     def deactivate(self):
         yield super().deactivate()
@@ -509,6 +552,4 @@ class Try_Userpass(TryBase):
         if not self.enabled:
             return
 
-        yield defer.gatherResults(
-            [reg.unregister() for reg in self.registrations], consumeErrors=True
-        )
+        yield self._destroy_pb()
