@@ -17,18 +17,19 @@
 import os
 import sys
 
-from buildbot import config
+from buildbot.config.errors import ConfigErrors
+from buildbot.config.master import FileLoader
 from buildbot.scripts.base import getConfigFileFromTac
 from buildbot.util import in_reactor
 
 
 def _loadConfig(basedir, configFile, quiet):
     try:
-        config.FileLoader(basedir, configFile).loadConfig()
-    except config.ConfigErrors as e:
+        FileLoader(basedir, configFile).loadConfig()
+    except ConfigErrors as err:
         if not quiet:
             print("Configuration Errors:", file=sys.stderr)
-            for e in e.errors:
+            for e in err.errors:
                 print("  " + e, file=sys.stderr)
         return 1
 
@@ -49,7 +50,7 @@ def checkconfig(config):
         except Exception:
             if not quiet:
                 # the exception is already printed in base.py
-                print("Unable to load 'buildbot.tac' from '{}':".format(basedir))
+                print(f"Unable to load 'buildbot.tac' from '{basedir}':")
             return 1
     else:
         basedir = os.getcwd()
