@@ -19,9 +19,9 @@ BuildSteps that are specific to the Twisted source tree
 from __future__ import annotations
 
 import re
+from typing import TYPE_CHECKING
 
 from twisted.internet import defer
-from twisted.internet.base import ReactorBase
 from twisted.python import log
 
 from buildbot import util
@@ -33,6 +33,9 @@ from buildbot.process.results import SUCCESS
 from buildbot.process.results import WARNINGS
 from buildbot.steps import shell
 
+if TYPE_CHECKING:
+    from twisted.internet.base import ReactorBase
+
 
 class HLint(buildstep.ShellMixin, buildstep.BuildStep):
     """I run a 'lint' checker over a set of .xhtml files. Any deviations
@@ -87,7 +90,7 @@ class HLint(buildstep.ShellMixin, buildstep.BuildStep):
         if cmd.didFail():
             return FAILURE
 
-        self.descriptionDone = f"{self.warnings} hlin{self.warnings == 1 and 't' or 'ts'}"
+        self.descriptionDone = f"{self.warnings} hlin{(self.warnings == 1 and 't') or 'ts'}"
 
         if self.warnings:
             return WARNINGS
@@ -378,7 +381,7 @@ class Trial(buildstep.ShellMixin, buildstep.BuildStep):
             if parsed:
                 results = SUCCESS
                 if total:
-                    desc_parts += [str(total), total == 1 and "test" or "tests", "passed"]
+                    desc_parts += [str(total), (total == 1 and "test") or "tests", "passed"]
                 else:
                     desc_parts += ["no tests", "run"]
             else:
@@ -390,14 +393,14 @@ class Trial(buildstep.ShellMixin, buildstep.BuildStep):
             if parsed:
                 desc_parts += ["tests"]
                 if failures:
-                    desc_parts += [str(failures), failures == 1 and "failure" or "failures"]
+                    desc_parts += [str(failures), (failures == 1 and "failure") or "failures"]
                 if errors:
-                    desc_parts += [str(errors), errors == 1 and "error" or "errors"]
+                    desc_parts += [str(errors), (errors == 1 and "error") or "errors"]
             else:
                 desc_parts += ["tests", "failed"]
 
         if counts['skips']:
-            desc_parts += [str(counts['skips']), counts['skips'] == 1 and "skip" or "skips"]
+            desc_parts += [str(counts['skips']), (counts['skips'] == 1 and "skip") or "skips"]
         if counts['expectedFailures']:
             desc_parts += [
                 str(counts['expectedFailures']),
