@@ -40,7 +40,6 @@ def deferUntilLater(secs, result=None):
 
 
 class LRUCacheFuzzer(fuzz.FuzzTestCase):
-
     FUZZ_TIME = 60
 
     def setUp(self):
@@ -49,8 +48,9 @@ class LRUCacheFuzzer(fuzz.FuzzTestCase):
     def tearDown(self):
         self.assertFalse(lru.inv_failed, "invariant failed; see logs")
         if hasattr(self, 'lru'):
-            log.msg("hits: %d; misses: %d; refhits: %d" % (self.lru.hits,
-                                                           self.lru.misses, self.lru.refhits))
+            log.msg(
+                f"hits: {self.lru.hits}; misses: {self.lru.misses}; refhits: {self.lru.refhits}"
+            )
 
     # tests
 
@@ -59,8 +59,8 @@ class LRUCacheFuzzer(fuzz.FuzzTestCase):
         lru.inv_failed = False
 
         def delayed_miss_fn(key):
-            return deferUntilLater(random.uniform(0.001, 0.002),
-                                   set([key + 1000]))
+            return deferUntilLater(random.uniform(0.001, 0.002), set([key + 1000]))
+
         self.lru = lru.AsyncLRUCache(delayed_miss_fn, 50)
 
         keys = list(range(250))
@@ -79,6 +79,7 @@ class LRUCacheFuzzer(fuzz.FuzzTestCase):
                 if random.uniform(0, 1.0) < 0.9:
                     results.append(result)
                     results[:-100] = []
+
             d.addCallback(check, key)
 
             @d.addErrback
@@ -98,5 +99,4 @@ class LRUCacheFuzzer(fuzz.FuzzTestCase):
             yield deferUntilLater(0.001)
 
         self.assertFalse(lru.inv_failed, "invariant failed; see logs")
-        log.msg("hits: %d; misses: %d; refhits: %d" % (self.lru.hits,
-                                                       self.lru.misses, self.lru.refhits))
+        log.msg(f"hits: {self.lru.hits}; misses: {self.lru.misses}; refhits: {self.lru.refhits}")
