@@ -46,7 +46,6 @@ class MySource(Source):
 
 
 class ShellMaster(RunMasterBase):
-
     @defer.inlineCallbacks
     def setup_config(self):
         c = {}
@@ -59,17 +58,16 @@ class ShellMaster(RunMasterBase):
         c['schedulers'] = [
             schedulers.ForceScheduler(
                 name="force",
-                codebases=[util.CodebaseParameter(
-                    "foo", patch=util.PatchParameter())],
-                builderNames=["testy"])]
+                codebases=[util.CodebaseParameter("foo", patch=util.PatchParameter())],
+                builderNames=["testy"],
+            )
+        ]
 
         f = BuildFactory()
         f.addStep(MySource(codebase='foo'))
         # if the patch was applied correctly, then make will work!
         f.addStep(steps.ShellCommand(command=["make"]))
-        c['builders'] = [
-            BuilderConfig(name="testy", workernames=["local1"], factory=f)
-        ]
+        c['builders'] = [BuilderConfig(name="testy", workernames=["local1"], factory=f)]
 
         yield self.setup_master(c)
 
@@ -77,8 +75,9 @@ class ShellMaster(RunMasterBase):
     @defer.inlineCallbacks
     def test_shell(self):
         yield self.setup_config()
-        build = yield self.doForceBuild(wantSteps=True, wantLogs=True,
-                                        forceParams={'foo_patch_body': PATCH})
+        build = yield self.doForceBuild(
+            wantSteps=True, wantLogs=True, forceParams={'foo_patch_body': PATCH}
+        )
         self.assertEqual(build['buildid'], 1)
         # if makefile was not properly created, we would have a failure
         self.assertEqual(build['results'], SUCCESS)
