@@ -21,7 +21,6 @@ from buildbot.test.util.integration import RunMasterBase
 
 
 class SecretsConfig(RunMasterBase):
-
     @defer.inlineCallbacks
     def setup_config(self, use_with=False):
         c = {}
@@ -30,25 +29,20 @@ class SecretsConfig(RunMasterBase):
         from buildbot.plugins import steps
         from buildbot.process.factory import BuildFactory
 
-        c['schedulers'] = [
-            schedulers.ForceScheduler(
-                name="force",
-                builderNames=["testy"])]
+        c['schedulers'] = [schedulers.ForceScheduler(name="force", builderNames=["testy"])]
 
-        c['secretsProviders'] = [FakeSecretStorage(
-            secretdict={"foo": "bar", "something": "more"})]
+        c['secretsProviders'] = [FakeSecretStorage(secretdict={"foo": "bar", "something": "more"})]
         f = BuildFactory()
         if use_with:
             secrets_list = [("pathA", Interpolate('%(secret:something)s'))]
             with f.withSecrets(secrets_list):
                 f.addStep(steps.ShellCommand(command=Interpolate('echo %(secret:foo)s')))
         else:
-            f.addSteps([steps.ShellCommand(command=Interpolate('echo %(secret:foo)s'))],
-                       withSecrets=[("pathA", Interpolate('%(secret:something)s'))])
-        c['builders'] = [
-            BuilderConfig(name="testy",
-                          workernames=["local1"],
-                          factory=f)]
+            f.addSteps(
+                [steps.ShellCommand(command=Interpolate('echo %(secret:foo)s'))],
+                withSecrets=[("pathA", Interpolate('%(secret:something)s'))],
+            )
+        c['builders'] = [BuilderConfig(name="testy", workernames=["local1"], factory=f)]
         yield self.setup_master(c)
 
     @defer.inlineCallbacks
