@@ -32,17 +32,11 @@ class TestLog(RunMasterBase):
         from buildbot.plugins import schedulers
         from buildbot.process.factory import BuildFactory
 
-        c['schedulers'] = [
-            schedulers.AnyBranchScheduler(
-                name="sched",
-                builderNames=["testy"])]
+        c['schedulers'] = [schedulers.AnyBranchScheduler(name="sched", builderNames=["testy"])]
 
         f = BuildFactory()
         f.addStep(step)
-        c['builders'] = [
-            BuilderConfig(name="testy",
-                          workernames=["local1"],
-                          factory=f)]
+        c['builders'] = [BuilderConfig(name="testy", workernames=["local1"], factory=f)]
         yield self.setup_master(c)
 
     @defer.inlineCallbacks
@@ -50,7 +44,6 @@ class TestLog(RunMasterBase):
         testcase = self
 
         class MyStep(steps.ShellCommand):
-
             def _newLog(self, name, type, logid, logEncoding):
                 r = super()._newLog(name, type, logid, logEncoding)
                 testcase.curr_log = r
@@ -67,7 +60,7 @@ class TestLog(RunMasterBase):
             "committer": "me@foo.com",
             "comments": "good stuff",
             "revision": "HEAD",
-            "project": "none"
+            "project": "none",
         }
         build = yield self.doForceBuild(wantSteps=True, useChange=change, wantLogs=True)
         self.assertEqual(build['buildid'], 1)
@@ -79,7 +72,6 @@ class TestLog(RunMasterBase):
         testcase = self
 
         class MyStep(steps.MasterShellCommand):
-
             def _newLog(self, name, type, logid, logEncoding):
                 r = super()._newLog(name, type, logid, logEncoding)
                 testcase.curr_log = r
@@ -96,7 +88,7 @@ class TestLog(RunMasterBase):
             "committer": "me@foo.com",
             "comments": "good stuff",
             "revision": "HEAD",
-            "project": "none"
+            "project": "none",
         }
         build = yield self.doForceBuild(wantSteps=True, useChange=change, wantLogs=True)
         self.assertEqual(build['buildid'], 1)
@@ -108,7 +100,6 @@ class TestLog(RunMasterBase):
         testcase = self
 
         class MyStep(steps.MasterShellCommand):
-
             def _newLog(self, name, type, logid, logEncoding):
                 r = super()._newLog(name, type, logid, logEncoding)
                 testcase.curr_log = r
@@ -126,7 +117,7 @@ class TestLog(RunMasterBase):
             "committer": "me@foo.com",
             "comments": "good stuff",
             "revision": "HEAD",
-            "project": "none"
+            "project": "none",
         }
         build = yield self.doForceBuild(wantSteps=True, useChange=change, wantLogs=True)
         self.assertEqual(build['buildid'], 1)
