@@ -190,14 +190,10 @@ class TestGitHubPullrequestPoller(
         yield secret_service.setServiceParent(self.master)
 
         yield self.master.startService()
+        self.addCleanup(self.master.stopService)
 
         fake_storage_service.reconfigService(secretdict={"token": "1234"})
 
-    @defer.inlineCallbacks
-    def tearDown(self):
-        yield self.master.stopService()
-        yield self.tearDownChangeSource()
-
     @defer.inlineCallbacks
     def newChangeSource(self, owner, repo, endpoint='https://api.github.com', **kwargs):
         http_headers = {'User-Agent': 'Buildbot'}
@@ -438,7 +434,8 @@ class TestGitHubPullrequestPoller(
             content_json=json.loads("[{}]"),
         )
         yield self.startChangeSource()
-        yield self.assertFailure(self.changesource.poll(), KeyError)
+        with self.assertRaises(KeyError):
+            yield self.changesource.poll()
 
     @defer.inlineCallbacks
     def test_failFiles(self):
@@ -464,7 +461,8 @@ class TestGitHubPullrequestPoller(
             content_json=json.loads("[{}]"),
         )
         yield self.startChangeSource()
-        yield self.assertFailure(self.changesource.poll(), KeyError)
+        with self.assertRaises(KeyError):
+            yield self.changesource.poll()
 
     @defer.inlineCallbacks
     def test_wrongRepoLink(self):
