@@ -212,7 +212,7 @@ class TestP4Poller(
                     'comments': 'creation',
                     'files': ['whatbranch'],
                     'project': '',
-                    'properties': {},
+                    'properties': None,
                     'repository': '',
                     'revision': '2',
                     'revlink': '',
@@ -229,7 +229,7 @@ class TestP4Poller(
                     'ASDF-GUI-P3-\u2018Upgrade Icon\u2019 disappears sometimes.',
                     'files': ['branch_b_file', 'whatbranch'],
                     'project': '',
-                    'properties': {},
+                    'properties': None,
                     'repository': '',
                     'revision': '3',
                     'revlink': '',
@@ -246,7 +246,7 @@ class TestP4Poller(
                     'ASDF-GUI-P3-\u2018Upgrade Icon\u2019 disappears sometimes.',
                     'files': ['whatbranch'],
                     'project': '',
-                    'properties': {},
+                    'properties': None,
                     'repository': '',
                     'revision': '3',
                     'revlink': '',
@@ -474,7 +474,7 @@ class TestP4Poller(
                         'Item 1\n\tItem 2',
                         'files': ['branch_c_file'],
                         'project': '',
-                        'properties': {},
+                        'properties': None,
                         'repository': '',
                         'revision': '5',
                         'revlink': '',
@@ -491,7 +491,7 @@ class TestP4Poller(
                         'Item 1\n\tItem 2',
                         'files': ['branch_b_file'],
                         'project': '',
-                        'properties': {},
+                        'properties': None,
                         'repository': '',
                         'revision': '5',
                         'revlink': '',
