@@ -501,7 +501,7 @@ class TestSVNPoller(
                     'comments': 'make_branch',
                     'files': [''],
                     'project': '',
-                    'properties': {},
+                    'properties': None,
                     'repository': 'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',
                     'revision': '2',
                     'revlink': '',
@@ -528,7 +528,7 @@ class TestSVNPoller(
                     'comments': 'commit_on_branch',
                     'files': ['çmain.c'],
                     'project': '',
-                    'properties': {},
+                    'properties': None,
                     'repository': 'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',
                     'revision': '3',
                     'revlink': '',
@@ -544,7 +544,7 @@ class TestSVNPoller(
                     'comments': 'revised_to_2',
                     'files': ['version.c'],
                     'project': '',
-                    'properties': {},
+                    'properties': None,
                     'repository': 'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',
                     'revision': '4',
                     'revlink': '',
@@ -643,7 +643,7 @@ class TestSVNPoller(
         self.assertEqual(s.last_change, 33)
 
         s.last_change = 44
-        s.finished_ok(None)
+        s.finished_ok()
         with open(cachepath, encoding='utf-8') as f:
             self.assertEqual(f.read().strip(), '44')
 
