@@ -37,6 +37,8 @@ from buildbot.config.master import FileLoader
 from buildbot.config.master import loadConfigDict
 from buildbot.process import factory
 from buildbot.process import properties
+from buildbot.process.codebase import Codebase
+from buildbot.process.project import Project
 from buildbot.schedulers import base as schedulers_base
 from buildbot.test.util import dirs
 from buildbot.test.util.config import ConfigErrorsMixin
@@ -98,6 +100,10 @@ class FakeWorker:
     def __init__(self, **kwargs):
         self.__dict__.update(kwargs)
 
+    @property
+    def workername(self):
+        return self.name
+
 
 @implementer(interfaces.IMachine)
 class FakeMachine:
@@ -243,7 +249,7 @@ class MasterConfigTests(ConfigErrorsMixin, dirs.DirsMixin, unittest.TestCase):
         cfg = config.master.MasterConfig()
         expected = {
             # validation,
-            "db": {"db_url": 'sqlite:///state.sqlite'},
+            "db": config.master.DBConfig(db_url='sqlite:///state.sqlite'),
             "mq": {"type": 'simple'},
             "metrics": None,
             "caches": {"Changes": 10, "Builds": 15},
@@ -320,7 +326,7 @@ class MasterConfigTests(ConfigErrorsMixin, dirs.DirsMixin, unittest.TestCase):
         # make sure all of the loaders and checkers are called
         self.assertTrue(rv.load_global.called)
         self.assertTrue(rv.load_validation.called)
-        self.assertTrue(rv.load_db.called)
+        self.assertTrue(rv.load_dbconfig.called)
         self.assertTrue(rv.load_metrics.called)
         self.assertTrue(rv.load_caches.called)
         self.assertTrue(rv.load_schedulers.called)
@@ -572,20 +578,22 @@ class MasterConfig_loaders(ConfigErrorsMixin, unittest.TestCase):
         self.assertIn('revision', self.cfg.validation)
 
     def test_load_db_defaults(self):
-        self.cfg.load_db(self.filename, {})
-        self.assertResults(db={"db_url": 'sqlite:///state.sqlite'})
+        self.cfg.load_dbconfig(self.filename, {})
+        self.assertResults(
+            db=config.master.DBConfig(db_url='sqlite:///state.sqlite', engine_kwargs={})
+        )
 
     def test_load_db_db_url(self):
-        self.cfg.load_db(self.filename, {"db_url": 'abcd'})
-        self.assertResults(db={"db_url": 'abcd'})
+        self.cfg.load_dbconfig(self.filename, {"db_url": 'abcd'})
+        self.assertResults(db=config.master.DBConfig(db_url='abcd'))
 
     def test_load_db_dict(self):
-        self.cfg.load_db(self.filename, {'db': {'db_url': 'abcd'}})
-        self.assertResults(db={"db_url": 'abcd'})
+        self.cfg.load_dbconfig(self.filename, {'db': {'db_url': 'abcd'}})
+        self.assertResults(db=config.master.DBConfig(db_url='abcd'))
 
     def test_load_db_unk_keys(self):
         with capture_config_errors() as errors:
-            self.cfg.load_db(self.filename, {'db': {'db_url': 'abcd', 'bar': 'bar'}})
+            self.cfg.load_dbconfig(self.filename, {'db': {'db_url': 'abcd', 'bar': 'bar'}})
 
         self.assertConfigError(errors, "unrecognized keys in")
 
@@ -699,7 +707,7 @@ class MasterConfig_loaders(ConfigErrorsMixin, unittest.TestCase):
         self.assertConfigError(errors, "scheduler name 'sch' used multiple times")
 
     def test_load_schedulers(self):
-        sch = schedulers_base.BaseScheduler('sch', [""])
+        sch = schedulers_base.ReconfigurableBaseScheduler(name='sch', builderNames=["a"])
         self.cfg.load_schedulers(self.filename, {"schedulers": [sch]})
         self.assertResults(schedulers={"sch": sch})
 
@@ -739,6 +747,40 @@ class MasterConfig_loaders(ConfigErrorsMixin, unittest.TestCase):
         self.cfg.load_builders(self.filename, {"builders": [bldr]})
         self.assertEqual(len(self.flushWarnings([self.cfg.load_builders])), 1)
 
+    def test_load_codebases_defaults(self):
+        self.cfg.load_codebases(self.filename, {})
+        self.assertResults(codebases=[])
+
+    def test_load_codebases_not_list(self):
+        with capture_config_errors() as errors:
+            self.cfg.load_codebases(self.filename, {'codebases': {}})
+        self.assertConfigError(errors, "must be a list")
+
+    def test_load_codebases_not_instance(self):
+        with capture_config_errors() as errors:
+            self.cfg.load_codebases(self.filename, {'codebases': [mock.Mock()]})
+
+        self.assertConfigError(errors, "is not a codebase config")
+
+    def test_load_codebases_not_project(self):
+        with capture_config_errors() as errors:
+            self.cfg.load_codebases(
+                self.filename, {'codebases': [Codebase(name='codebase', project='project')]}
+            )
+
+        self.assertConfigError(errors, "includes unknown project")
+
+    def test_load_codebases_valid(self):
+        cfg = {
+            'projects': [Project(name='project')],
+            'codebases': [Codebase(name='codebase', project='project')],
+        }
+
+        self.cfg.load_projects(self.filename, cfg)
+        self.cfg.load_codebases(self.filename, cfg)
+
+        self.assertResults(codebases=[Codebase(name='codebase', project='project')])
+
     def test_load_workers_defaults(self):
         self.cfg.load_workers(self.filename, {})
         self.assertResults(workers=[])
