@@ -44,7 +44,7 @@ class LogChunkEndpointBase(endpoint.EndpointMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield self.setUpEndpoint()
-        yield self.db.insert_test_data(
+        yield self.master.db.insert_test_data(
             [
                 fakedb.Builder(id=77),
                 fakedb.Worker(id=13, name='wrk'),
