@@ -36,7 +36,7 @@ class ProjectEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield self.setUpEndpoint()
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Project(id=1, name='project1'),
             fakedb.Project(id=2, name='project2'),
         ])
@@ -75,7 +75,7 @@ class ProjectsEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield self.setUpEndpoint()
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Project(id=1, name='project1'),
             fakedb.Project(id=2, name='project2'),
             fakedb.Project(id=3, name='project3'),
@@ -121,7 +121,7 @@ class Project(interfaces.InterfaceTests, TestReactorMixin, unittest.TestCase):
             self.master.data.updates.find_project_id,  # fake
             self.rtype.find_project_id,
         )  # real
-        def find_project_id(self, name):
+        def find_project_id(self, name: str, auto_create: bool = True):
             pass
 
     def test_find_project_id(self):
