@@ -35,7 +35,7 @@ class BuildsetPropertiesEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield self.setUpEndpoint()
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Buildset(id=13, reason='because I said so'),
             fakedb.SourceStamp(id=92),
             fakedb.SourceStamp(id=93),
@@ -59,7 +59,7 @@ class BuildPropertiesEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield self.setUpEndpoint()
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Builder(id=1),
             fakedb.Buildset(id=28),
             fakedb.BuildRequest(id=5, buildsetid=28, builderid=1),
@@ -98,7 +98,9 @@ class Properties(interfaces.InterfaceTests, TestReactorMixin, unittest.TestCase)
         setattr(self.master.db.builds, dbMethodName, m)
         res = yield method(*args, **kwargs)
         self.assertIdentical(res, rv)
-        m.assert_called_with(*(exp_args or args), **((exp_kwargs is None) and kwargs or exp_kwargs))
+        m.assert_called_with(
+            *(exp_args or args), **(((exp_kwargs is None) and kwargs) or exp_kwargs)
+        )
 
     def test_signature_setBuildProperty(self):
         @self.assertArgSpecMatches(
