@@ -24,6 +24,7 @@ from buildbot.test.fake import fakemaster
 from buildbot.test.reactor import TestReactorMixin
 from buildbot.test.util import endpoint
 from buildbot.test.util import interfaces
+from buildbot.util.twisted import async_to_deferred
 
 
 class TestResultSetEndpoint(endpoint.EndpointMixin, unittest.TestCase):
@@ -33,7 +34,7 @@ class TestResultSetEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield self.setUpEndpoint()
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Worker(id=47, name='linux'),
             fakedb.Buildset(id=20),
             fakedb.Builder(id=88, name='b1'),
@@ -88,7 +89,7 @@ class TestResultSetsEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield self.setUpEndpoint()
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Worker(id=47, name='linux'),
             fakedb.Buildset(id=20),
             fakedb.Builder(id=88, name='b1'),
@@ -156,6 +157,101 @@ class TestResultSetsEndpoint(endpoint.EndpointMixin, unittest.TestCase):
         self.assertEqual([r['test_result_setid'] for r in results], [13, 14])
 
 
+class TestResultSetsFromCommitRangeEndpoint(endpoint.EndpointMixin, unittest.TestCase):
+    endpointClass = test_result_sets.TestResultSetsFromCommitRangeEndpoint
+    resourceTypeClass = test_result_sets.TestResultSet
+
+    @async_to_deferred
+    async def setUp(self) -> None:  # type: ignore[override]
+        await self.setUpEndpoint()
+
+        master_id = fakedb.FakeDBConnector.MASTER_ID
+        await self.master.db.insert_test_data([
+            fakedb.Master(id=master_id),
+            fakedb.Worker(id=47, name='linux'),
+            fakedb.Project(id=100),
+            fakedb.Codebase(id=200, projectid=100),
+            fakedb.CodebaseCommit(id=300, codebaseid=200, revision='rev300'),
+            fakedb.CodebaseCommit(id=301, codebaseid=200, revision='rev301', parent_commitid=300),
+            fakedb.CodebaseCommit(id=302, codebaseid=200, revision='rev302', parent_commitid=301),
+            fakedb.CodebaseCommit(id=303, codebaseid=200, revision='rev303', parent_commitid=302),
+            fakedb.CodebaseCommit(id=304, codebaseid=200, revision='rev304', parent_commitid=303),
+            fakedb.Buildset(id=4000),
+            fakedb.Buildset(id=4010),
+            fakedb.Buildset(id=4020),
+            fakedb.Buildset(id=4021),
+            fakedb.Buildset(id=4040),
+            fakedb.SourceStamp(id=5000, revision='rev300'),
+            fakedb.SourceStamp(id=5010, revision='rev301'),
+            fakedb.SourceStamp(id=5020, revision='rev302'),
+            fakedb.SourceStamp(id=5040, revision='rev304'),
+            fakedb.BuildsetSourceStamp(id=6000, buildsetid=4000, sourcestampid=5000),
+            fakedb.BuildsetSourceStamp(id=6001, buildsetid=4010, sourcestampid=5010),
+            fakedb.BuildsetSourceStamp(id=6002, buildsetid=4020, sourcestampid=5020),
+            fakedb.BuildsetSourceStamp(id=6003, buildsetid=4021, sourcestampid=5020),
+            fakedb.BuildsetSourceStamp(id=6004, buildsetid=4040, sourcestampid=5040),
+            fakedb.Builder(id=400, name='b1'),
+            fakedb.BuildRequest(id=7000, buildsetid=4000, builderid=400),
+            fakedb.BuildRequest(id=7010, buildsetid=4010, builderid=400),
+            fakedb.BuildRequest(id=7020, buildsetid=4020, builderid=400),
+            fakedb.BuildRequest(id=7021, buildsetid=4021, builderid=400),
+            fakedb.BuildRequest(id=7040, buildsetid=4040, builderid=400),
+            fakedb.Build(
+                id=8000, buildrequestid=7000, masterid=master_id, builderid=400, workerid=47
+            ),
+            fakedb.Build(
+                id=8010, buildrequestid=7010, masterid=master_id, builderid=400, workerid=47
+            ),
+            fakedb.Build(
+                id=8020, buildrequestid=7020, masterid=master_id, builderid=400, workerid=47
+            ),
+            fakedb.Build(
+                id=8021, buildrequestid=7021, masterid=master_id, builderid=400, workerid=47
+            ),
+            fakedb.Build(
+                id=8040, buildrequestid=7040, masterid=master_id, builderid=400, workerid=47
+            ),
+            fakedb.Step(id=9000, buildid=8000),
+            fakedb.Step(id=9010, buildid=8010),
+            fakedb.Step(id=9020, buildid=8020),
+            fakedb.Step(id=9021, buildid=8021),
+            fakedb.Step(id=9040, buildid=8040),
+            fakedb.TestResultSet(id=10000, builderid=400, buildid=8000, stepid=9000),
+            fakedb.TestResultSet(id=10010, builderid=400, buildid=8010, stepid=9010),
+            fakedb.TestResultSet(id=10020, builderid=400, buildid=8020, stepid=9020),
+            fakedb.TestResultSet(id=10021, builderid=400, buildid=8021, stepid=9021),
+            fakedb.TestResultSet(id=10040, builderid=400, buildid=8040, stepid=9040),
+        ])
+
+    @async_to_deferred
+    async def test_get_full_range(self) -> None:
+        results = await self.callGet((
+            'codebases',
+            200,
+            'commit_range',
+            300,
+            304,
+            'test_result_sets',
+        ))
+        for result in results:
+            self.validateData(result)
+        self.assertEqual(
+            [r['test_result_setid'] for r in results], [10000, 10010, 10020, 10021, 10040]
+        )
+
+    @async_to_deferred
+    async def test_get_opposite_range(self) -> None:
+        results = await self.callGet((
+            'codebases',
+            200,
+            'commit_range',
+            304,
+            300,
+            'test_result_sets',
+        ))
+        self.assertEqual(results, [])
+
+
 class TestResultSet(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
