@@ -15,22 +15,19 @@
 
 
 from twisted.internet import defer
+from twisted.trial import unittest
 
-from buildbot.db import state
 from buildbot.test import fakedb
-from buildbot.test.util import connector_component
-from buildbot.test.util import db
+from buildbot.test.fake import fakemaster
+from buildbot.test.reactor import TestReactorMixin
 
 
-class TestStateConnectorComponent(connector_component.ConnectorComponentMixin, db.TestCase):
+class TestStateConnectorComponent(TestReactorMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
-        yield self.setUpConnectorComponent(table_names=['objects', 'object_state'])
-
-        self.db.state = state.StateConnectorComponent(self.db)
-
-    def tearDown(self):
-        return self.tearDownConnectorComponent()
+        self.setup_test_reactor()
+        self.master = yield fakemaster.make_master(self, wantDb=True)
+        self.db = self.master.db
 
     @defer.inlineCallbacks
     def test_getObjectId_new(self):
@@ -49,7 +46,9 @@ class TestStateConnectorComponent(connector_component.ConnectorComponentMixin, d
 
     @defer.inlineCallbacks
     def test_getObjectId_existing(self):
-        yield self.insert_test_data([fakedb.Object(id=19, name='someobj', class_name='someclass')])
+        yield self.db.insert_test_data([
+            fakedb.Object(id=19, name='someobj', class_name='someclass')
+        ])
         objectid = yield self.db.state.getObjectId('someobj', 'someclass')
 
         self.assertEqual(objectid, 19)
@@ -87,9 +86,11 @@ class TestStateConnectorComponent(connector_component.ConnectorComponentMixin, d
 
         yield self.db.pool.do(thd)
 
+    @defer.inlineCallbacks
     def test_getState_missing(self):
-        d = self.db.state.getState(10, 'nosuch')
-        return self.assertFailure(d, KeyError)
+        with self.assertRaises(KeyError):
+            yield self.db.state.getState(10, 'nosuch')
+        self.flushLoggedErrors(KeyError)
 
     @defer.inlineCallbacks
     def test_getState_missing_default(self):
@@ -105,7 +106,7 @@ class TestStateConnectorComponent(connector_component.ConnectorComponentMixin, d
 
     @defer.inlineCallbacks
     def test_getState_present(self):
-        yield self.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.Object(id=10, name='x', class_name='y'),
             fakedb.ObjectState(objectid=10, name='x', value_json='[1,2]'),
         ])
@@ -113,17 +114,19 @@ class TestStateConnectorComponent(connector_component.ConnectorComponentMixin, d
 
         self.assertEqual(val, [1, 2])
 
+    @defer.inlineCallbacks
     def test_getState_badjson(self):
-        d = self.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.Object(id=10, name='x', class_name='y'),
             fakedb.ObjectState(objectid=10, name='x', value_json='ff[1'),
         ])
-        d.addCallback(lambda _: self.db.state.getState(10, 'x'))
-        return self.assertFailure(d, TypeError)
+        with self.assertRaises(TypeError):
+            yield self.db.state.getState(10, 'x')
+        self.flushLoggedErrors(TypeError)
 
     @defer.inlineCallbacks
     def test_setState(self):
-        yield self.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.Object(id=10, name='-', class_name='-'),
         ])
         yield self.db.state.setState(10, 'x', [1, 2])
@@ -137,16 +140,18 @@ class TestStateConnectorComponent(connector_component.ConnectorComponentMixin, d
 
         yield self.db.pool.do(thd)
 
+    @defer.inlineCallbacks
     def test_setState_badjson(self):
-        d = self.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.Object(id=10, name='x', class_name='y'),
         ])
-        d.addCallback(lambda _: self.db.state.setState(10, 'x', self))  # self is not JSON-able..
-        return self.assertFailure(d, TypeError)
+        with self.assertRaises(TypeError):
+            yield self.db.state.setState(10, 'x', self)  # self is not JSON-able..
+        self.flushLoggedErrors(TypeError)
 
     @defer.inlineCallbacks
     def test_setState_existing(self):
-        yield self.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.Object(id=10, name='-', class_name='-'),
             fakedb.ObjectState(objectid=10, name='x', value_json='99'),
         ])
@@ -171,7 +176,7 @@ class TestStateConnectorComponent(connector_component.ConnectorComponentMixin, d
 
         self.db.state._test_timing_hook = hook
 
-        yield self.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.Object(id=10, name='-', class_name='-'),
         ])
         yield self.db.state.setState(10, 'x', [1, 2])
@@ -185,7 +190,7 @@ class TestStateConnectorComponent(connector_component.ConnectorComponentMixin, d
 
     @defer.inlineCallbacks
     def test_atomicCreateState(self):
-        yield self.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.Object(id=10, name='-', class_name='-'),
         ])
         res = yield self.db.state.atomicCreateState(10, 'x', lambda: [1, 2])
@@ -195,7 +200,7 @@ class TestStateConnectorComponent(connector_component.ConnectorComponentMixin, d
 
     @defer.inlineCallbacks
     def test_atomicCreateState_conflict(self):
-        yield self.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.Object(id=10, name='-', class_name='-'),
         ])
 
@@ -214,9 +219,10 @@ class TestStateConnectorComponent(connector_component.ConnectorComponentMixin, d
 
     @defer.inlineCallbacks
     def test_atomicCreateState_nojsonable(self):
-        yield self.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.Object(id=10, name='-', class_name='-'),
         ])
 
-        d = self.db.state.atomicCreateState(10, 'x', object)
-        yield self.assertFailure(d, TypeError)
+        with self.assertRaises(TypeError):
+            yield self.db.state.atomicCreateState(10, 'x', object)
+        self.flushLoggedErrors(TypeError)
