@@ -15,9 +15,9 @@
 from __future__ import annotations
 
 import re
+from typing import TYPE_CHECKING
 from typing import Any
 from typing import Callable
-from typing import Generator
 from unittest import mock
 
 from twisted.internet import defer
@@ -32,8 +32,11 @@ from buildbot.test.fake import fakemaster
 from buildbot.test.reactor import TestReactorMixin
 from buildbot.util import datetime2epoch
 
+if TYPE_CHECKING:
+    from buildbot.util.twisted import InlineCallbacksType
 
-class ContactMixin(TestReactorMixin):
+
+class ContactMixin(TestReactorMixin, unittest.TestCase):
     botClass = words.StatusBot
 
     channelClass = words.Channel
@@ -47,7 +50,7 @@ class ContactMixin(TestReactorMixin):
     patch: Callable[[Any, str, Any], Any]
 
     @defer.inlineCallbacks
-    def setUp(self) -> Generator[Any, None, None]:
+    def setUp(self) -> InlineCallbacksType[None]:  # type: ignore[override]
         self.setup_test_reactor()
         self.patch(reactor, 'callLater', self.reactor.callLater)
         self.patch(reactor, 'seconds', self.reactor.seconds)
@@ -57,6 +60,7 @@ class ContactMixin(TestReactorMixin):
 
         yield self.master.db.insert_test_data(
             [
+                fakedb.Master(id=fakedb.FakeDBConnector.MASTER_ID),
                 fakedb.Master(id=88),
                 fakedb.Worker(id=13, name='w13'),
             ]
