@@ -16,7 +16,6 @@
 from unittest import mock
 
 from twisted.internet import defer
-from twisted.internet import task
 from twisted.trial import unittest
 
 from buildbot import config
@@ -38,9 +37,6 @@ class CommonStuffMixin:
         ])
         sched = yield self.attachScheduler(klass(**kwargs), self.OBJECTID, self.SCHEDULERID)
 
-        # add a Clock to help checking timing issues
-        self.clock = sched._reactor = task.Clock()
-
         # keep track of builds in self.events
         self.events = []
 
@@ -57,7 +53,7 @@ class CommonStuffMixin:
         ):
             self.assertEqual(external_idstring, None)
             self.assertEqual(reason, sched.reason)
-            self.events.append(f"B{repr(changeids).replace(' ', '')}@{int(self.clock.seconds())}")
+            self.events.append(f"B{repr(changeids).replace(' ', '')}@{int(self.reactor.seconds())}")
             return defer.succeed(None)
 
         sched.addBuildsetForChanges = addBuildsetForChanges
@@ -115,7 +111,7 @@ class BaseBasicScheduler(
         chd['changeid'] = chd['number']
         sourcestampid = chd['number'] + 100
         del chd['number']
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Change(sourcestampid=sourcestampid, **chd),
             fakedb.SourceStamp(id=sourcestampid),
         ])
@@ -124,14 +120,14 @@ class BaseBasicScheduler(
     # tests
 
     def test_constructor_positional_exception(self):
-        with self.assertRaises(config.ConfigErrors):
+        with self.assertRaises(TypeError):
             self.Subclass("tsched", "master", 60)
 
     @defer.inlineCallbacks
     def test_activate_no_treeStableTimer(self):
         cf = mock.Mock('cf')
         fII = mock.Mock('fII')
-        sched = yield self.makeScheduler(
+        yield self.makeScheduler(
             self.Subclass, treeStableTimer=None, change_filter=cf, fileIsImportant=fII
         )
 
@@ -140,24 +136,14 @@ class BaseBasicScheduler(
             fakedb.Change(changeid=20),
         ])
 
-        yield self.db.schedulers.classifyChanges(self.SCHEDULERID, {20: True})
+        yield self.master.db.schedulers.classifyChanges(self.SCHEDULERID, {20: True})
 
-        yield sched.activate()
+        yield self.master.startService()
 
         # check that the scheduler has started to consume changes, and the
         # classifications *have* been flushed, since they will not be used
         self.assertConsumingChanges(fileIsImportant=fII, change_filter=cf, onlyImportant=False)
         yield self.assert_classifications(self.SCHEDULERID, {})
-        yield sched.deactivate()
-
-    @defer.inlineCallbacks
-    def test_subclass_fileIsImportant(self):
-        class Subclass(self.Subclass):
-            def fileIsImportant(self, change):
-                return False
-
-        sched = yield self.makeScheduler(Subclass, onlyImportant=True)
-        self.assertEqual(Subclass.fileIsImportant.__get__(sched), sched.fileIsImportant)
 
     @defer.inlineCallbacks
     def test_activate_treeStableTimer(self):
@@ -168,9 +154,9 @@ class BaseBasicScheduler(
             fakedb.SourceStamp(id=92),
             fakedb.Change(changeid=20),
         ])
-        yield self.db.schedulers.classifyChanges(self.SCHEDULERID, {20: True})
+        yield self.master.db.schedulers.classifyChanges(self.SCHEDULERID, {20: True})
 
-        yield sched.activate()
+        yield self.master.startService()
 
         # check that the scheduler has started to consume changes, and no
         # classifications have been flushed.  Furthermore, the existing
@@ -179,60 +165,49 @@ class BaseBasicScheduler(
         self.assertConsumingChanges(fileIsImportant=None, change_filter=cf, onlyImportant=False)
         yield self.assert_classifications(self.SCHEDULERID, {20: True})
         self.assertTrue(sched.timer_started)
-        self.clock.advance(10)
-        yield sched.deactivate()
+        self.reactor.advance(10)
 
     @defer.inlineCallbacks
     def test_gotChange_no_treeStableTimer_unimportant(self):
         sched = yield self.makeScheduler(self.Subclass, treeStableTimer=None, branch='master')
-
-        sched.activate()
+        yield self.master.startService()
 
         yield sched.gotChange((yield self.mkch(branch='master', number=13)), False)
 
         self.assertEqual(self.events, [])
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_gotChange_no_treeStableTimer_important(self):
         sched = yield self.makeScheduler(self.Subclass, treeStableTimer=None, branch='master')
 
-        sched.activate()
+        yield self.master.startService()
 
         yield sched.gotChange((yield self.mkch(branch='master', number=13)), True)
 
         self.assertEqual(self.events, ['B[13]@0'])
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_gotChange_treeStableTimer_unimportant(self):
         sched = yield self.makeScheduler(self.Subclass, treeStableTimer=10, branch='master')
-
-        sched.activate()
+        yield self.master.startService()
 
         yield sched.gotChange((yield self.mkch(branch='master', number=13)), False)
 
         self.assertEqual(self.events, [])
-        self.clock.advance(10)
+        self.reactor.advance(10)
         self.assertEqual(self.events, [])
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_gotChange_treeStableTimer_important(self):
         sched = yield self.makeScheduler(self.Subclass, treeStableTimer=10, branch='master')
 
-        sched.activate()
+        yield self.master.startService()
 
         yield sched.gotChange((yield self.mkch(branch='master', number=13)), True)
-        self.clock.advance(10)
+        self.reactor.advance(10)
 
         self.assertEqual(self.events, ['B[13]@10'])
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_gotChange_treeStableTimer_sequence(self):
         sched = yield self.makeScheduler(self.Subclass, treeStableTimer=9, branch='master')
@@ -247,9 +222,9 @@ class BaseBasicScheduler(
             fakedb.Change(changeid=4, branch='master', when_timestamp=4440),
             fakedb.ChangeFile(changeid=4, filename='readme.txt'),
         ])
-        sched.activate()
+        yield self.master.startService()
 
-        self.clock.advance(2220)
+        self.reactor.advance(2220)
 
         # this important change arrives at 2220, so the stable timer will last
         # until 2229
@@ -258,17 +233,17 @@ class BaseBasicScheduler(
         yield self.assert_classifications(self.SCHEDULERID, {1: True})
 
         # but another (unimportant) change arrives before then
-        self.clock.advance(6)  # to 2226
+        self.reactor.advance(6)  # to 2226
         self.assertEqual(self.events, [])
 
         yield sched.gotChange(self.makeFakeChange(branch='master', number=2, when=2226), False)
         self.assertEqual(self.events, [])
         yield self.assert_classifications(self.SCHEDULERID, {1: True, 2: False})
 
-        self.clock.advance(3)  # to 2229
+        self.reactor.advance(3)  # to 2229
         self.assertEqual(self.events, [])
 
-        self.clock.advance(3)  # to 2232
+        self.reactor.advance(3)  # to 2232
         self.assertEqual(self.events, [])
 
         # another important change arrives at 2232
@@ -276,19 +251,19 @@ class BaseBasicScheduler(
         self.assertEqual(self.events, [])
         yield self.assert_classifications(self.SCHEDULERID, {1: True, 2: False, 3: True})
 
-        self.clock.advance(3)  # to 2235
+        self.reactor.advance(3)  # to 2235
         self.assertEqual(self.events, [])
 
         # finally, time to start the build!
-        self.clock.advance(6)  # to 2241
+        self.reactor.advance(6)  # to 2241
         self.assertEqual(self.events, ['B[1,2,3]@2241'])
         yield self.assert_classifications(self.SCHEDULERID, {})
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_enabled_callback(self):
         sched = yield self.makeScheduler(self.Subclass)
+        yield self.master.startService()
+
         expectedValue = not sched.enabled
         yield sched._enabledCallback(None, {'enabled': not sched.enabled})
         self.assertEqual(sched.enabled, expectedValue)
@@ -335,9 +310,6 @@ class SingleBranchScheduler(
             self.SCHEDULERID,
             overrideBuildsetMethods=True,
         )
-
-        # add a Clock to help checking timing issues
-        self.clock = sched._reactor = task.Clock()
         return sched
 
     def mkbs(self, **kwargs):
@@ -367,7 +339,7 @@ class SingleBranchScheduler(
         chd['changeid'] = chd['number']
         sourcestampid = chd['number'] + 100
         del chd['number']
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Change(sourcestampid=sourcestampid, **chd),
             fakedb.SourceStamp(id=sourcestampid),
         ])
@@ -381,6 +353,7 @@ class SingleBranchScheduler(
     @defer.inlineCallbacks
     def test_constructor_no_reason(self):
         sched = yield self.makeScheduler(basic.SingleBranchScheduler, branch="master")
+        yield sched.configureService()
         self.assertEqual(
             sched.reason, "The SingleBranchScheduler scheduler named 'tsched' triggered this build"
         )
@@ -390,6 +363,7 @@ class SingleBranchScheduler(
         sched = yield self.makeScheduler(
             basic.SingleBranchScheduler, branch="master", reason="Changeset"
         )
+        yield sched.configureService()
         self.assertEqual(sched.reason, "Changeset")
 
     def test_constructor_branch_mandatory(self):
@@ -411,11 +385,13 @@ class SingleBranchScheduler(
         sched = yield self.makeScheduler(
             basic.SingleBranchScheduler, branch="master", priority=None
         )
+        yield sched.configureService()
         self.assertEqual(sched.priority, None)
 
     @defer.inlineCallbacks
     def test_constructor_priority_int(self):
         sched = yield self.makeScheduler(basic.SingleBranchScheduler, branch="master", priority=8)
+        yield sched.configureService()
         self.assertEqual(sched.priority, 8)
 
     @defer.inlineCallbacks
@@ -426,6 +402,7 @@ class SingleBranchScheduler(
         sched = yield self.makeScheduler(
             basic.SingleBranchScheduler, branch="master", priority=sched_priority
         )
+        yield sched.configureService()
         self.assertEqual(sched.priority, sched_priority)
 
     @defer.inlineCallbacks
@@ -436,16 +413,14 @@ class SingleBranchScheduler(
             basic.SingleBranchScheduler, treeStableTimer=10, branch='master'
         )
 
-        sched.activate()
+        yield self.master.startService()
 
         change = yield self.mkch(branch='master', number=13)
         yield sched.gotChange(change, True)
-        self.clock.advance(10)
+        self.reactor.advance(10)
 
         self.assertEqual(self.events, ['B[13]@10'])
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_gotChange_createAbsoluteSourceStamps_saveCodebase(self):
         # check codebase is stored after receiving change.
@@ -457,11 +432,10 @@ class SingleBranchScheduler(
             codebases=self.codebases,
             createAbsoluteSourceStamps=True,
         )
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Object(id=self.OBJECTID, name='test', class_name='SingleBranchScheduler')
         ])
-
-        yield sched.activate()
+        yield self.master.startService()
 
         yield sched.gotChange(
             (yield self.mkch(codebase='a', revision='1234:abc', repository='A', number=1)), True
@@ -488,8 +462,6 @@ class SingleBranchScheduler(
             },
         )
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_gotChange_createAbsoluteSourceStamps_older_change(self):
         # check codebase is not stored if it's older than the most recent
@@ -501,7 +473,7 @@ class SingleBranchScheduler(
             codebases=self.codebases,
             createAbsoluteSourceStamps=True,
         )
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Object(id=self.OBJECTID, name='test', class_name='SingleBranchScheduler'),
             fakedb.ObjectState(
                 objectid=self.OBJECTID,
@@ -511,7 +483,7 @@ class SingleBranchScheduler(
             ),
         ])
 
-        yield sched.activate()
+        yield self.master.startService()
 
         # this change is not recorded, since it's older than
         # change 20
@@ -531,8 +503,6 @@ class SingleBranchScheduler(
             },
         )
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_getCodebaseDict(self):
         sched = yield self.makeFullScheduler(
@@ -543,6 +513,7 @@ class SingleBranchScheduler(
             codebases=self.codebases,
             createAbsoluteSourceStamps=True,
         )
+        yield self.master.startService()
         sched._lastCodebases = {
             'a': {"branch": 'master', "repository": 'A', "revision": '5555:def', "lastChange": 20}
         }
@@ -562,6 +533,7 @@ class SingleBranchScheduler(
             codebases=self.codebases,
             createAbsoluteSourceStamps=False,
         )
+        yield self.master.startService()
         sched._lastCodebases = {
             'a': {"branch": 'master', "repository": 'A', "revision": '5555:def', "lastChange": 20}
         }
@@ -575,11 +547,11 @@ class SingleBranchScheduler(
         sched = yield self.makeFullScheduler(
             name='test', builderNames=['test'], branch='master', priority=8
         )
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Object(id=self.OBJECTID, name='test', class_name='SingleBranchScheduler')
         ])
 
-        yield sched.activate()
+        yield self.master.startService()
 
         yield sched.gotChange(
             (yield self.mkch(codebase='a', revision='1234:abc', repository='A', number=10)), True
@@ -603,8 +575,6 @@ class SingleBranchScheduler(
             ],
         )
 
-        yield sched.deactivate()
-
 
 class AnyBranchScheduler(
     CommonStuffMixin, scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase
@@ -628,7 +598,7 @@ class AnyBranchScheduler(
             basic.AnyBranchScheduler, treeStableTimer=10, branches=['master', 'devel', 'boring']
         )
 
-        sched.activate()
+        yield self.master.startService()
 
         @defer.inlineCallbacks
         def mkch(**kwargs):
@@ -637,17 +607,15 @@ class AnyBranchScheduler(
             return ch
 
         yield sched.gotChange((yield mkch(branch='master', number=500)), True)
-        yield self.clock.advance(1)  # time is now 1
+        yield self.reactor.advance(1)  # time is now 1
         yield sched.gotChange((yield mkch(branch='master', number=501)), False)
         yield sched.gotChange((yield mkch(branch='boring', number=502)), False)
-        yield self.clock.pump([1] * 4)  # time is now 5
+        yield self.reactor.pump([1] * 4)  # time is now 5
         yield sched.gotChange((yield mkch(branch='devel', number=503)), True)
-        yield self.clock.pump([1] * 10)  # time is now 15
+        yield self.reactor.pump([1] * 10)  # time is now 15
 
         self.assertEqual(self.events, ['B[500,501]@11', 'B[503]@15'])
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_gotChange_treeStableTimer_multiple_repositories(self):
         """Two repositories, even with the same branch name, have different treeStableTimers"""
@@ -655,7 +623,7 @@ class AnyBranchScheduler(
             basic.AnyBranchScheduler, treeStableTimer=10, branches=['master']
         )
 
-        yield sched.activate()
+        yield self.master.startService()
 
         @defer.inlineCallbacks
         def mkch(**kwargs):
@@ -664,21 +632,19 @@ class AnyBranchScheduler(
             return ch
 
         yield sched.gotChange((yield mkch(branch='master', repository="repo", number=500)), True)
-        yield self.clock.advance(1)  # time is now 1
+        yield self.reactor.advance(1)  # time is now 1
         yield sched.gotChange((yield mkch(branch='master', repository="repo", number=501)), False)
         yield sched.gotChange(
             (yield mkch(branch='master', repository="other_repo", number=502)), False
         )
-        yield self.clock.pump([1] * 4)  # time is now 5
+        yield self.reactor.pump([1] * 4)  # time is now 5
         yield sched.gotChange(
             (yield mkch(branch='master', repository="other_repo", number=503)), True
         )
-        yield self.clock.pump([1] * 10)  # time is now 15
+        yield self.reactor.pump([1] * 10)  # time is now 15
 
         self.assertEqual(self.events, ['B[500,501]@11', 'B[502,503]@15'])
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_gotChange_treeStableTimer_multiple_projects(self):
         """Two projects, even with the same branch name, have different treeStableTimers"""
@@ -686,7 +652,7 @@ class AnyBranchScheduler(
             basic.AnyBranchScheduler, treeStableTimer=10, branches=['master']
         )
 
-        sched.startService()
+        yield self.master.startService()
 
         @defer.inlineCallbacks
         def mkch(**kwargs):
@@ -695,19 +661,17 @@ class AnyBranchScheduler(
             return ch
 
         yield sched.gotChange((yield mkch(branch='master', project="proj", number=500)), True)
-        yield self.clock.advance(1)  # time is now 1
+        yield self.reactor.advance(1)  # time is now 1
         yield sched.gotChange((yield mkch(branch='master', project="proj", number=501)), False)
         yield sched.gotChange(
             (yield mkch(branch='master', project="other_proj", number=502)), False
         )
-        yield self.clock.pump([1] * 4)  # time is now 5
+        yield self.reactor.pump([1] * 4)  # time is now 5
         yield sched.gotChange((yield mkch(branch='master', project="other_proj", number=503)), True)
-        yield self.clock.pump([1] * 10)  # time is now 15
+        yield self.reactor.pump([1] * 10)  # time is now 15
 
         self.assertEqual(self.events, ['B[500,501]@11', 'B[502,503]@15'])
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_gotChange_treeStableTimer_multiple_codebases(self):
         """Two codebases, even with the same branch name, have different treeStableTimers"""
@@ -715,7 +679,7 @@ class AnyBranchScheduler(
             basic.AnyBranchScheduler, treeStableTimer=10, branches=['master']
         )
 
-        sched.startService()
+        yield self.master.startService()
 
         @defer.inlineCallbacks
         def mkch(**kwargs):
@@ -724,17 +688,15 @@ class AnyBranchScheduler(
             return ch
 
         yield sched.gotChange((yield mkch(branch='master', codebase="base", number=500)), True)
-        self.clock.advance(1)  # time is now 1
+        self.reactor.advance(1)  # time is now 1
         yield sched.gotChange((yield mkch(branch='master', codebase="base", number=501)), False)
         yield sched.gotChange(
             (yield mkch(branch='master', codebase="other_base", number=502)), False
         )
-        self.clock.pump([1] * 4)  # time is now 5
+        self.reactor.pump([1] * 4)  # time is now 5
         yield sched.gotChange(
             (yield mkch(branch='master', codebase="other_base", number=503)), True
         )
-        self.clock.pump([1] * 10)  # time is now 15
+        self.reactor.pump([1] * 10)  # time is now 15
 
         self.assertEqual(self.events, ['B[500,501]@11', 'B[502,503]@15'])
-
-        yield sched.deactivate()
