@@ -54,8 +54,6 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
             fakedb.Builder(name=bname) for bname in kwargs.get("builderNames", [])
         ])
 
-        # add a Clock to help checking timing issues
-        sched._reactor = self.reactor
         self.reactor.advance(self.time_offset)
 
         self.addBuildsetCallTimes = []
@@ -111,7 +109,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
         # fakedb.Change requires changeid instead of number
         chd['changeid'] = chd['number']
         del chd['number']
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Change(**chd),
             fakedb.SourceStamp(id=92),
         ])
@@ -130,6 +128,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
     @defer.inlineCallbacks
     def test_constructor_no_reason(self):
         sched = yield self.makeScheduler(name='test', builderNames=['test'], branch='default')
+        yield sched.configureService()
         self.assertEqual(sched.reason, "The Nightly scheduler named 'test' triggered this build")
 
     @defer.inlineCallbacks
@@ -137,6 +136,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
         sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch='default', reason="hourly"
         )
+        yield sched.configureService()
         self.assertEqual(sched.reason, "hourly")
 
     @defer.inlineCallbacks
@@ -147,6 +147,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
             branch=None,
             change_filter=filter.ChangeFilter(category_re="fo+o"),
         )
+        yield sched.configureService()
         assert sched.change_filter
 
     @defer.inlineCallbacks
@@ -154,6 +155,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
         sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch='default', month='1'
         )
+        yield sched.configureService()
         self.assertEqual(sched.month, "1")
 
     @defer.inlineCallbacks
@@ -161,6 +163,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
         sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch='default', priority=None
         )
+        yield sched.configureService()
         self.assertEqual(sched.priority, None)
 
     @defer.inlineCallbacks
@@ -168,6 +171,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
         sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch='default', priority=8
         )
+        yield sched.configureService()
         self.assertEqual(sched.priority, 8)
 
     @defer.inlineCallbacks
@@ -178,11 +182,13 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
         sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch='default', priority=sched_priority
         )
+        yield sched.configureService()
         self.assertEqual(sched.priority, sched_priority)
 
     @defer.inlineCallbacks
     def test_enabled_callback(self):
         sched = yield self.makeScheduler(name='test', builderNames=['test'], branch='default')
+        yield sched.configureService()
         expectedValue = not sched.enabled
         yield sched._enabledCallback(None, {'enabled': not sched.enabled})
         self.assertEqual(sched.enabled, expectedValue)
@@ -222,15 +228,15 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
         # starts at midnight UTC, so be careful not to use times that are
         # timezone dependent -- stick to minutes-past-the-half-hour, as some
         # timezones are multiples of 30 minutes off from UTC
-        sched = yield self.makeScheduler(
+        yield self.makeScheduler(
             name='test', builderNames=['test'], branch=None, minute=[10, 20, 21, 40, 50, 51]
         )
         yield self.mkch(number=19)
 
         # add a change classification
-        yield self.db.schedulers.classifyChanges(self.SCHEDULERID, {19: True})
+        yield self.master.db.schedulers.classifyChanges(self.SCHEDULERID, {19: True})
 
-        yield sched.activate()
+        yield self.master.startService()
 
         # check that the classification has been flushed, since this
         # invocation has not requested onlyIfChanged
@@ -280,16 +286,15 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
         )
         yield self.assert_state_by_class('test', 'Nightly', last_build=1260 + self.time_offset)
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def test_iterations_simple_with_branch(self):
         # see timezone warning above
         sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch='master', minute=[5, 35]
         )
+        yield self.master.startService()
 
-        sched.activate()
+        yield sched.activate()
 
         self.reactor.advance(0)
         while self.reactor.seconds() < self.time_offset + 10 * 60:
@@ -313,8 +318,6 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
         )
         yield self.assert_state_by_class('test', 'Nightly', last_build=300 + self.time_offset)
 
-        yield sched.deactivate()
-
     @defer.inlineCallbacks
     def do_test_iterations_onlyIfChanged(
         self, changes_at, last_only_if_changed, is_new_scheduler=False, **kwargs
@@ -340,7 +343,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unitte
 
     @defer.inlineCallbacks
     def do_test_iterations_onlyIfChanged_test(self, fII, changes_at):
-        yield self.sched.activate()
+        yield self.master.startService()
 
         # check that the scheduler has started to consume changes
         self.assertConsumingChanges(fileIsImportant=fII, change_filter=None, onlyImportant=False)
