@@ -14,7 +14,6 @@
 # Copyright Buildbot Team Members
 
 from twisted.internet import defer
-from twisted.internet import task
 from twisted.trial import unittest
 
 from buildbot.process import properties
@@ -40,10 +39,6 @@ class NightlyTriggerable(
             overrideBuildsetMethods=True,
             createBuilderDB=True,
         )
-
-        # add a Clock to help checking timing issues
-        self.clock = sched._reactor = task.Clock()
-
         return sched
 
     @defer.inlineCallbacks
@@ -85,6 +80,7 @@ class NightlyTriggerable(
     @defer.inlineCallbacks
     def test_constructor_no_reason(self):
         sched = yield self.makeScheduler(name='test', builderNames=['test'])
+        yield sched.configureService()
         self.assertEqual(
             sched.reason, "The NightlyTriggerable scheduler named 'test' triggered this build"
         )
@@ -94,19 +90,21 @@ class NightlyTriggerable(
         sched = yield self.makeScheduler(
             name='test', builderNames=['test'], reason="hourlytriggerable"
         )
+        yield sched.configureService()
         self.assertEqual(sched.reason, "hourlytriggerable")
 
     @defer.inlineCallbacks
     def test_constructor_month(self):
         sched = yield self.makeScheduler(name='test', builderNames=['test'], month='1')
+        yield sched.configureService()
         self.assertEqual(sched.month, "1")
 
     @defer.inlineCallbacks
     def test_timer_noBuilds(self):
-        sched = yield self.makeScheduler(name='test', builderNames=['test'], minute=[5])
+        yield self.makeScheduler(name='test', builderNames=['test'], minute=[5])
+        yield self.master.startService()
 
-        sched.activate()
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         self.assertEqual(self.addBuildsetCalls, [])
 
@@ -118,8 +116,7 @@ class NightlyTriggerable(
             minute=[5],
             codebases={'cb': {'repository': 'annoying'}},
         )
-
-        sched.activate()
+        yield self.master.startService()
 
         sched.trigger(
             False,
@@ -135,7 +132,7 @@ class NightlyTriggerable(
             set_props=None,
         )
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         self.assertBuildsetAdded(
             sourcestamps=[
@@ -158,7 +155,7 @@ class NightlyTriggerable(
             codebases={'cb': {'repository': 'annoying'}},
         )
 
-        sched.activate()
+        yield self.master.startService()
 
         sched.trigger(
             False,
@@ -187,7 +184,7 @@ class NightlyTriggerable(
             set_props=None,
         )
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         self.assertBuildsetAdded(
             sourcestamps=[
@@ -211,7 +208,7 @@ class NightlyTriggerable(
             codebases={'cb': {'repository': 'annoying'}},
         )
 
-        sched.activate()
+        yield self.master.startService()
 
         sched.trigger(
             False,
@@ -227,7 +224,7 @@ class NightlyTriggerable(
             set_props=None,
         )
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         self.assertBuildsetAdded(
             sourcestamps=[
@@ -241,7 +238,7 @@ class NightlyTriggerable(
             ]
         )
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         # no trigger, so the second did not build
         self.assertNoBuildsetAdded()
@@ -255,7 +252,7 @@ class NightlyTriggerable(
             codebases={'cb': {'repository': 'annoying'}},
         )
 
-        sched.activate()
+        yield self.master.startService()
 
         sched.trigger(
             False,
@@ -271,7 +268,7 @@ class NightlyTriggerable(
             set_props=None,
         )
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         self.assertBuildsetAdded(
             sourcestamps=[
@@ -299,7 +296,7 @@ class NightlyTriggerable(
             set_props=None,
         )
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         self.assertBuildsetAdded(
             sourcestamps=[
@@ -315,7 +312,7 @@ class NightlyTriggerable(
 
     @defer.inlineCallbacks
     def test_savedTrigger(self):
-        sched = yield self.makeScheduler(
+        yield self.makeScheduler(
             name='test',
             builderNames=['test'],
             minute=[5],
@@ -327,16 +324,16 @@ class NightlyTriggerable(
             '"branch": "br", "revision": "myrev"} ], {}, null, null ]'
         )
 
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Object(id=self.SCHEDULERID, name='test', class_name='NightlyTriggerable'),
             fakedb.ObjectState(
                 objectid=self.SCHEDULERID, name='lastTrigger', value_json=value_json
             ),
         ])
 
-        sched.activate()
+        yield self.master.startService()
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         self.assertBuildsetAdded(
             sourcestamps=[
@@ -352,7 +349,7 @@ class NightlyTriggerable(
 
     @defer.inlineCallbacks
     def test_savedTrigger_dict(self):
-        sched = yield self.makeScheduler(
+        yield self.makeScheduler(
             name='test',
             builderNames=['test'],
             minute=[5],
@@ -363,16 +360,16 @@ class NightlyTriggerable(
             '[ { "cb": {"codebase": "cb", "project": "p", "repository": "r", '
             '"branch": "br", "revision": "myrev"} }, {}, null, null ]'
         )
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Object(id=self.SCHEDULERID, name='test', class_name='NightlyTriggerable'),
             fakedb.ObjectState(
                 objectid=self.SCHEDULERID, name='lastTrigger', value_json=value_json
             ),
         ])
 
-        sched.activate()
+        yield self.master.startService()
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         self.assertBuildsetAdded(
             sourcestamps=[
@@ -394,11 +391,11 @@ class NightlyTriggerable(
             minute=[5],
             codebases={'cb': {'repository': 'annoying'}},
         )
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Object(id=self.SCHEDULERID, name='test', class_name='NightlyTriggerable'),
         ])
 
-        sched.activate()
+        yield self.master.startService()
 
         _, d = sched.trigger(
             False,
@@ -441,11 +438,11 @@ class NightlyTriggerable(
             minute=[5],
             codebases={'cb': {'repository': 'annoying'}},
         )
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Object(id=self.SCHEDULERID, name='test', class_name='NightlyTriggerable'),
         ])
 
-        sched.activate()
+        yield self.master.startService()
 
         _, d = sched.trigger(
             False,
@@ -461,7 +458,7 @@ class NightlyTriggerable(
             set_props=None,
         )
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         yield d
         yield self.assert_state(self.SCHEDULERID, lastTrigger=None)
@@ -474,11 +471,11 @@ class NightlyTriggerable(
             minute=[5],
             codebases={'cb': {'repository': 'annoying'}},
         )
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Object(id=self.SCHEDULERID, name='test', class_name='NightlyTriggerable'),
         ])
 
-        sched.activate()
+        yield self.master.startService()
 
         sched.trigger(
             False,
@@ -512,7 +509,7 @@ class NightlyTriggerable(
             ],
         )
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         self.assertBuildsetAdded(
             properties={"testprop": ('test', 'TEST')},
@@ -529,7 +526,7 @@ class NightlyTriggerable(
 
     @defer.inlineCallbacks
     def test_savedProperties(self):
-        sched = yield self.makeScheduler(
+        yield self.makeScheduler(
             name='test',
             builderNames=['test'],
             minute=[5],
@@ -541,16 +538,16 @@ class NightlyTriggerable(
             '"branch": "br", "revision": "myrev"} ], '
             '{"testprop": ["test", "TEST"]}, null, null ]'
         )
-        yield self.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Object(id=self.SCHEDULERID, name='test', class_name='NightlyTriggerable'),
             fakedb.ObjectState(
                 objectid=self.SCHEDULERID, name='lastTrigger', value_json=value_json
             ),
         ])
 
-        sched.activate()
+        yield self.master.startService()
 
-        self.clock.advance(60 * 60)  # Run for 1h
+        self.reactor.advance(60 * 60)  # Run for 1h
 
         self.assertBuildsetAdded(
             properties={'testprop': ('test', 'TEST')},
