@@ -123,6 +123,44 @@ class TestMasterShellCommand(TestBuildStepMixin, TestReactorMixin, unittest.Test
             del os.environ['WORLD']
             del os.environ['LIST']
 
+    @defer.inlineCallbacks
+    def test_runtime_timeout_success(self):
+        """Test the runtime_timeout argument."""
+        runtime_timeout = 10
+        n_ping = 1
+        cmd = f'ping 127.0.0.1 -n {n_ping}'
+
+        if sys.platform == 'win32':
+            exp_argv = [r'C:\WINDOWS\system32\cmd.exe', '/c', cmd]
+        else:
+            exp_argv = ['/bin/sh', '-c', cmd]
+
+        self.setup_step(master.MasterShellCommand(command=cmd, runtime_timeout=runtime_timeout))
+
+        self.expect_commands(ExpectMasterShell(exp_argv).exit(0))
+        self.expect_outcome(result=SUCCESS)
+
+        yield self.run_step()
+
+    @defer.inlineCallbacks
+    def test_runtime_timeout_failed(self):
+        """Test the runtime_timeout argument aborts the step."""
+        runtime_timeout = 1
+        n_ping = 10
+        cmd = f'ping 127.0.0.1 -n {n_ping}'
+
+        if sys.platform == 'win32':
+            exp_argv = [r'C:\WINDOWS\system32\cmd.exe', '/c', cmd]
+        else:
+            exp_argv = ['/bin/sh', '-c', cmd]
+
+        self.setup_step(master.MasterShellCommand(command=cmd, runtime_timeout=runtime_timeout))
+
+        self.expect_commands(ExpectMasterShell(exp_argv).exit(2))
+        self.expect_outcome(result=FAILURE)
+
+        yield self.run_step()
+
     def test_prop_rendering(self):
         self.setup_step(
             master.MasterShellCommand(
