@@ -96,9 +96,6 @@ class Trial(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_run_env(self):
         self.setup_step(
             python_twisted.Trial(
@@ -400,9 +397,6 @@ class HLint(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_run_ok(self):
         self.setup_build(build_files=['foo.xhtml'])
         self.setup_step(python_twisted.HLint(workdir='build'))
@@ -469,9 +463,6 @@ class RemovePYCs(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_run_ok(self):
         self.setup_step(python_twisted.RemovePYCs())
         self.expect_commands(
