@@ -231,9 +231,6 @@ class VisualStudio(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_default_config(self):
         vs = vstudio.VisualStudio()
         self.assertEqual(vs.config, 'release')
@@ -352,9 +349,6 @@ class TestVC6(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def getExpectedEnv(self, installdir, LIB=None, p=None, i=None):
         include = [
             installdir + r'\VC98\INCLUDE;',
@@ -450,9 +444,6 @@ class TestVC7(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def getExpectedEnv(self, installdir, LIB=None, p=None, i=None):
         include = [
             installdir + r'\VC7\INCLUDE;',
@@ -585,9 +576,6 @@ class TestVC8(VC8ExpectedEnvMixin, TestBuildStepMixin, TestReactorMixin, unittes
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_args(self):
         self.setup_step(vstudio.VC8(projectfile='pf', config='cfg', project='pj', arch='arch'))
         self.expect_commands(
@@ -646,9 +634,6 @@ class TestVCExpress9(VC8ExpectedEnvMixin, TestBuildStepMixin, TestReactorMixin,
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_args(self):
         self.setup_step(vstudio.VCExpress9(projectfile='pf', config='cfg', project='pj'))
         self.expect_commands(
@@ -703,9 +688,6 @@ class TestVC9(VC8ExpectedEnvMixin, TestBuildStepMixin, TestReactorMixin, unittes
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_installdir(self):
         self.setup_step(vstudio.VC9(projectfile='pf', config='cfg', project='pj'))
         self.expect_commands(
@@ -724,9 +706,6 @@ class TestVC10(VC8ExpectedEnvMixin, TestBuildStepMixin, TestReactorMixin, unitte
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_installdir(self):
         self.setup_step(vstudio.VC10(projectfile='pf', config='cfg', project='pj'))
         self.expect_commands(
@@ -745,9 +724,6 @@ class TestVC11(VC8ExpectedEnvMixin, TestBuildStepMixin, TestReactorMixin, unitte
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_installdir(self):
         self.setup_step(vstudio.VC11(projectfile='pf', config='cfg', project='pj'))
         self.expect_commands(
@@ -766,9 +742,6 @@ class TestMsBuild(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     @defer.inlineCallbacks
     def test_no_platform(self):
         self.setup_step(
@@ -868,9 +841,6 @@ class TestMsBuild141(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     @defer.inlineCallbacks
     def test_no_platform(self):
         self.setup_step(
@@ -988,9 +958,6 @@ class TestMsBuild16(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_version_range_is_correct(self):
         self.setup_step(
             vstudio.MsBuild16(projectfile='pf', config='cfg', platform='Win32', project='pj')
@@ -1015,9 +982,6 @@ class TestMsBuild17(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_version_range_is_correct(self):
         self.setup_step(
             vstudio.MsBuild17(projectfile='pf', config='cfg', platform='Win32', project='pj')
