@@ -16,7 +16,6 @@
 from unittest import mock
 
 from parameterized import parameterized
-
 from twisted.internet import defer
 from twisted.trial import unittest
 
@@ -34,7 +33,6 @@ class Requester:
 
 
 class BaseLockTests(unittest.TestCase):
-
     @parameterized.expand([
         ('counting', 0, 0),
         ('counting', 0, 1),
@@ -253,8 +251,7 @@ class BaseLockTests(unittest.TestCase):
         ('counting', 3, 3),
         ('exclusive', 1, 1),
     ])
-    def test_duplicate_wait_until_maybe_available_throws(self, mode, count,
-            maxCount):
+    def test_duplicate_wait_until_maybe_available_throws(self, mode, count, maxCount):
         req = Requester()
         req_waiter = Requester()
 
@@ -275,8 +272,7 @@ class BaseLockTests(unittest.TestCase):
         ('counting', 3, 3),
         ('exclusive', 1, 1),
     ])
-    def test_stop_waiting_ensures_deferred_was_previous_result_of_wait(self,
-            mode, count, maxCount):
+    def test_stop_waiting_ensures_deferred_was_previous_result_of_wait(self, mode, count, maxCount):
         req = Requester()
         req_waiter = Requester()
 
@@ -300,8 +296,7 @@ class BaseLockTests(unittest.TestCase):
         ('counting', 3, 3),
         ('exclusive', 1, 1),
     ])
-    def test_stop_waiting_fires_deferred_if_not_woken(self, mode, count,
-            maxCount):
+    def test_stop_waiting_fires_deferred_if_not_woken(self, mode, count, maxCount):
         req = Requester()
         req_waiter = Requester()
 
@@ -324,8 +319,7 @@ class BaseLockTests(unittest.TestCase):
         ('exclusive', 1, 1),
     ])
     @defer.inlineCallbacks
-    def test_stop_waiting_does_not_fire_deferred_if_already_woken(self, mode,
-            count, maxCount):
+    def test_stop_waiting_does_not_fire_deferred_if_already_woken(self, mode, count, maxCount):
         req = Requester()
         req_waiter = Requester()
 
@@ -350,8 +344,7 @@ class BaseLockTests(unittest.TestCase):
         ('counting', 3, 3),
         ('exclusive', 1, 1),
     ])
-    def test_stop_waiting_does_not_raise_after_release(self, mode, count,
-            maxCount):
+    def test_stop_waiting_does_not_raise_after_release(self, mode, count, maxCount):
         req = Requester()
         req_waiter = Requester()
 
@@ -416,8 +409,7 @@ class BaseLockTests(unittest.TestCase):
         ('exclusive', 1, 1),
     ])
     @defer.inlineCallbacks
-    def test_stop_waiting_wakes_up_next_deferred_if_already_woken(self, mode,
-            count, maxCount):
+    def test_stop_waiting_wakes_up_next_deferred_if_already_woken(self, mode, count, maxCount):
         req = Requester()
         req_waiter1 = Requester()
         req_waiter2 = Requester()
@@ -471,8 +463,7 @@ class BaseLockTests(unittest.TestCase):
         ('exclusive', 'exclusive', 1, 1, 1),
     ])
     @defer.inlineCallbacks
-    def test_release_calls_waiters_in_fifo_order(self, mode1, mode2, count1,
-            count2, maxCount):
+    def test_release_calls_waiters_in_fifo_order(self, mode1, mode2, count1, count2, maxCount):
         req = Requester()
 
         req_waiters = [Requester() for _ in range(5)]
@@ -489,8 +480,10 @@ class BaseLockTests(unittest.TestCase):
         expected_called = [False] * 5
 
         lock.claim(req, access1)
-        deferreds = [lock.waitUntilMaybeAvailable(req_waiter, access)
-                     for req_waiter, access in zip(req_waiters, accesses)]
+        deferreds = [
+            lock.waitUntilMaybeAvailable(req_waiter, access)
+            for req_waiter, access in zip(req_waiters, accesses)
+        ]
         self.assertEqual([d.called for d in deferreds], expected_called)
 
         lock.release(req, access1)
@@ -515,7 +508,7 @@ class BaseLockTests(unittest.TestCase):
         lock.release(req_waiters[4], accesses[4])
 
     @parameterized.expand([
-        (1, ),
+        (1,),
     ])
     @defer.inlineCallbacks
     def test_release_calls_multiple_waiters_on_release(self, count):
@@ -532,8 +525,9 @@ class BaseLockTests(unittest.TestCase):
         access_excl.count = 1
 
         lock.claim(req, access_excl)
-        deferreds = [lock.waitUntilMaybeAvailable(req_waiter, access_counting)
-                     for req_waiter in req_waiters]
+        deferreds = [
+            lock.waitUntilMaybeAvailable(req_waiter, access_counting) for req_waiter in req_waiters
+        ]
         self.assertEqual([d.called for d in deferreds], [False] * 5)
 
         lock.release(req, access_excl)
@@ -545,8 +539,7 @@ class BaseLockTests(unittest.TestCase):
         (1, 1),
     ])
     @defer.inlineCallbacks
-    def test_release_calls_multiple_waiters_on_setMaxCount(self, count,
-            maxCount):
+    def test_release_calls_multiple_waiters_on_setMaxCount(self, count, maxCount):
         req = Requester()
 
         req_waiters = [Requester() for _ in range(5)]
@@ -557,8 +550,9 @@ class BaseLockTests(unittest.TestCase):
         access_counting.count = count
 
         lock.claim(req, access_counting)
-        deferreds = [lock.waitUntilMaybeAvailable(req_waiter, access_counting)
-                     for req_waiter in req_waiters]
+        deferreds = [
+            lock.waitUntilMaybeAvailable(req_waiter, access_counting) for req_waiter in req_waiters
+        ]
         self.assertEqual([d.called for d in deferreds], [False] * 5)
 
         lock.release(req, access_counting)
@@ -577,8 +571,7 @@ class BaseLockTests(unittest.TestCase):
         (4, 4),
         (5, 5),
     ])
-    def test_exclusive_must_have_count_one(self, count,
-            maxCount):
+    def test_exclusive_must_have_count_one(self, count, maxCount):
         req = Requester()
 
         lock = BaseLock('test', maxCount=maxCount)
@@ -600,9 +593,7 @@ class BaseLockTests(unittest.TestCase):
         (2, 3),
         (3, 3),
     ])
-    def test_counting_count_zero_always_succeeds(self, count,
-            maxCount):
-
+    def test_counting_count_zero_always_succeeds(self, count, maxCount):
         reqs = [Requester() for _ in range(10)]
         req_waiters = [Requester() for _ in range(10)]
         req_nonzero = Requester()
@@ -635,9 +626,7 @@ class BaseLockTests(unittest.TestCase):
         (3, 1),
         (3, 2),
     ])
-    def test_count_cannot_be_larger_than_maxcount(self, count,
-            maxCount):
-
+    def test_count_cannot_be_larger_than_maxcount(self, count, maxCount):
         req = Requester()
 
         lock = BaseLock('test', maxCount=maxCount)
@@ -657,9 +646,7 @@ class BaseLockTests(unittest.TestCase):
         (2, 3, 5),
         (2, 3, 6),
     ])
-    def test_different_counts_below_limit(self, count1, count2,
-            maxCount):
-
+    def test_different_counts_below_limit(self, count1, count2, maxCount):
         req1 = Requester()
         req2 = Requester()
 
@@ -688,9 +675,7 @@ class BaseLockTests(unittest.TestCase):
         (2, 3, 4),
         (2, 4, 4),
     ])
-    def test_different_counts_over_limit(self, count1, count2,
-            maxCount):
-
+    def test_different_counts_over_limit(self, count1, count2, maxCount):
         req1 = Requester()
         req2 = Requester()
 
@@ -709,7 +694,6 @@ class BaseLockTests(unittest.TestCase):
 
 
 class RealLockTests(unittest.TestCase):
-
     def test_master_lock_init_from_lockid(self):
         lock = RealMasterLock('lock1')
         lock.updateFromLockId(MasterLock('lock1', maxCount=3), 0)
@@ -741,13 +725,11 @@ class RealLockTests(unittest.TestCase):
         worker_lock = lock.getLockForWorker('worker1')
         self.assertEqual(worker_lock.lockName, 'lock1')
         self.assertEqual(worker_lock.maxCount, 3)
-        self.assertTrue(worker_lock.description.startswith(
-            '<WorkerLock(lock1, 3)[worker1]'))
+        self.assertTrue(worker_lock.description.startswith('<WorkerLock(lock1, 3)[worker1]'))
 
     def test_worker_lock_init_from_lockid_count_for_worker(self):
         lock = RealWorkerLock('lock1')
-        lock.updateFromLockId(WorkerLock('lock1', maxCount=3,
-                                         maxCountForWorker={'worker2': 5}), 0)
+        lock.updateFromLockId(WorkerLock('lock1', maxCount=3, maxCountForWorker={'worker2': 5}), 0)
 
         self.assertEqual(lock.lockName, 'lock1')
         self.assertEqual(lock.maxCount, 3)
@@ -772,8 +754,7 @@ class RealLockTests(unittest.TestCase):
 
         self.assertEqual(worker_lock.lockName, 'lock1')
         self.assertEqual(worker_lock.maxCount, 5)
-        self.assertTrue(worker_lock.description.startswith(
-            '<WorkerLock(lock1, 5)[worker1]'))
+        self.assertTrue(worker_lock.description.startswith('<WorkerLock(lock1, 5)[worker1]'))
 
         with self.assertRaises(AssertionError):
             lock.updateFromLockId(WorkerLock('lock2', maxCount=4), 0)
@@ -789,8 +770,8 @@ class RealLockTests(unittest.TestCase):
         (False, False, False),
     ])
     def test_worker_lock_update_from_lockid_count_for_worker(
-            self, acquire_before, worker_count_before, worker_count_after):
-
+        self, acquire_before, worker_count_before, worker_count_after
+    ):
         max_count_before = {}
         if worker_count_before:
             max_count_before = {'worker1': 5}
@@ -799,20 +780,18 @@ class RealLockTests(unittest.TestCase):
             max_count_after = {'worker1': 7}
 
         lock = RealWorkerLock('lock1')
-        lock.updateFromLockId(WorkerLock('lock1', maxCount=3,
-                                         maxCountForWorker=max_count_before), 0)
+        lock.updateFromLockId(
+            WorkerLock('lock1', maxCount=3, maxCountForWorker=max_count_before), 0
+        )
 
         if acquire_before:
             worker_lock = lock.getLockForWorker('worker1')
-            self.assertEqual(worker_lock.maxCount,
-                             5 if worker_count_before else 3)
+            self.assertEqual(worker_lock.maxCount, 5 if worker_count_before else 3)
 
-        lockid = WorkerLock('lock1', maxCount=4,
-                            maxCountForWorker=max_count_after)
+        lockid = WorkerLock('lock1', maxCount=4, maxCountForWorker=max_count_after)
         lock.updateFromLockId(lockid, 0)
 
         if not acquire_before:
             worker_lock = lock.getLockForWorker('worker1')
 
-        self.assertEqual(worker_lock.maxCount,
-                         7 if worker_count_after else 4)
+        self.assertEqual(worker_lock.maxCount, 7 if worker_count_after else 4)
