@@ -53,7 +53,7 @@ class FailingLoader:
 class DefaultLoader:
     def loadConfig(self):
         master_cfg = MasterConfig()
-        master_cfg.db['db_url'] = Interpolate('sqlite:///path-to-%(secret:db_pwd)s-db-file')
+        master_cfg.db.db_url = Interpolate('sqlite:///path-to-%(secret:db_pwd)s-db-file')
         master_cfg.secretsProviders = [FakeSecretStorage(secretdict={'db_pwd': 's3cr3t'})]
         return master_cfg
 
@@ -100,21 +100,26 @@ class StartupAndReconfig(dirs.DirsMixin, logging.LoggingMixin, TestReactorMixin,
         self.master.caches = fakemaster.FakeCaches()
         self.secrets_manager = self.master.secrets_manager = SecretManager()
         yield self.secrets_manager.setServiceParent(self.master)
-        self.db = self.master.db = fakedb.FakeDBConnector(self.basedir, self, auto_upgrade=True)
-        yield self.db.set_master(self.master)
+        self.master.db = fakedb.FakeDBConnector(self.basedir, self, auto_upgrade=True)
+        yield self.master.db.set_master(self.master)
 
         @defer.inlineCallbacks
         def cleanup():
-            if self.db.pool is not None:
-                yield self.db.pool.stop()
+            if self.master.db.pool is not None:
+                yield self.master.db.pool.stop()
 
         self.addCleanup(cleanup)
 
-        self.mq = self.master.mq = fakemq.FakeMQConnector(self)
-        yield self.mq.setServiceParent(self.master)
+        self.master.mq = fakemq.FakeMQConnector(self)
+        yield self.master.mq.setServiceParent(self.master)
         self.data = self.master.data = fakedata.FakeDataConnector(self.master, self)
         yield self.data.setServiceParent(self.master)
 
+    @defer.inlineCallbacks
+    def assert_this_master_active(self, active):
+        masters = yield self.master.data.get(('masters', 1))
+        self.assertEqual(masters['active'], active)
+
     # tests
     @defer.inlineCallbacks
     def test_startup_bad_config(self):
@@ -132,7 +137,7 @@ class StartupAndReconfig(dirs.DirsMixin, logging.LoggingMixin, TestReactorMixin,
             log.msg("GOT HERE")
             raise exceptions.DatabaseNotReadyError()
 
-        self.db.setup = db_setup
+        self.master.db.setup = db_setup
 
         yield self.master.startService()
 
@@ -145,7 +150,7 @@ class StartupAndReconfig(dirs.DirsMixin, logging.LoggingMixin, TestReactorMixin,
         def db_setup():
             raise RuntimeError("oh noes")
 
-        self.db.setup = db_setup
+        self.master.db.setup = db_setup
 
         yield self.master.startService()
 
@@ -158,24 +163,24 @@ class StartupAndReconfig(dirs.DirsMixin, logging.LoggingMixin, TestReactorMixin,
         yield self.master.startService()
 
         self.assertEqual(
-            self.master.db.configured_url,
+            self.master.db.configured_db_config.db_url,
             'sqlite:///path-to-s3cr3t-db-file',
         )
 
-        self.assertTrue(self.master.data.updates.thisMasterActive)
+        yield self.assert_this_master_active(True)
         d = self.master.stopService()
         self.assertTrue(d.called)
         self.assertFalse(self.reactor.stop_called)
         self.assertLogged("BuildMaster is running")
 
         # check started/stopped messages
-        self.assertFalse(self.master.data.updates.thisMasterActive)
+        yield self.assert_this_master_active(False)
 
     @defer.inlineCallbacks
     def test_startup_ok_waitforshutdown(self):
         yield self.master.startService()
 
-        self.assertTrue(self.master.data.updates.thisMasterActive)
+        yield self.assert_this_master_active(True)
         # use fakebotmaster shutdown delaying
         self.master.botmaster.delayShutdown = True
         d = self.master.stopService()
@@ -183,7 +188,7 @@ class StartupAndReconfig(dirs.DirsMixin, logging.LoggingMixin, TestReactorMixin,
         self.assertFalse(d.called)
 
         # master must only send shutdown once builds are completed
-        self.assertTrue(self.master.data.updates.thisMasterActive)
+        yield self.assert_this_master_active(True)
         self.master.botmaster.shutdownDeferred.callback(None)
         self.assertTrue(d.called)
 
@@ -191,7 +196,7 @@ class StartupAndReconfig(dirs.DirsMixin, logging.LoggingMixin, TestReactorMixin,
         self.assertLogged("BuildMaster is running")
 
         # check started/stopped messages
-        self.assertFalse(self.master.data.updates.thisMasterActive)
+        yield self.assert_this_master_active(False)
 
     @defer.inlineCallbacks
     def test_reconfig(self):
@@ -226,15 +231,15 @@ class StartupAndReconfig(dirs.DirsMixin, logging.LoggingMixin, TestReactorMixin,
     @defer.inlineCallbacks
     def test_reconfigService_db_url_changed(self):
         old = self.master.config = MasterConfig()
-        old.db['db_url'] = Interpolate('sqlite:///%(secret:db_pwd)s')
+        old.db.db_url = Interpolate('sqlite:///%(secret:db_pwd)s')
         old.secretsProviders = [FakeSecretStorage(secretdict={'db_pwd': 's3cr3t'})]
         yield self.master.secrets_manager.setup()
         yield self.master.db.setup()
         yield self.master.reconfigServiceWithBuildbotConfig(old)
-        self.assertEqual(self.master.db.configured_url, 'sqlite:///s3cr3t')
+        self.assertEqual(self.master.db.configured_db_config.db_url, 'sqlite:///s3cr3t')
 
         new = MasterConfig()
-        new.db['db_url'] = old.db['db_url']
+        new.db.db_url = old.db.db_url
         new.secretsProviders = [FakeSecretStorage(secretdict={'db_pwd': 'other-s3cr3t'})]
 
         with self.assertRaises(config.ConfigErrors):
