@@ -16,7 +16,6 @@
 from unittest.mock import patch
 
 from parameterized import parameterized
-
 from twisted.internet import defer
 from twisted.trial import unittest
 
@@ -28,6 +27,7 @@ from buildbot.test.util.config import ConfigErrorsMixin
 
 try:
     import hvac
+
     assert hvac
 except ImportError:
     hvac = None
@@ -102,17 +102,14 @@ def mock_vault(*args, **kwargs):
 
 
 class TestSecretInVaultAuthenticator(interfaces.InterfaceTests):
-
     def test_authenticate(self):
         raise NotImplementedError
 
 
 class TestSecretInVaultAuthenticatorToken(unittest.TestCase, TestSecretInVaultAuthenticator):
-
     def setUp(self):
         if hvac is None:
-            raise unittest.SkipTest(
-                "Need to install hvac to test VaultAuthenticatorToken")
+            raise unittest.SkipTest("Need to install hvac to test VaultAuthenticatorToken")
 
     def test_authenticate(self):
         token = "mockToken"
@@ -123,7 +120,6 @@ class TestSecretInVaultAuthenticatorToken(unittest.TestCase, TestSecretInVaultAu
 
 
 class TestSecretInVaultAuthenticatorApprole(unittest.TestCase, TestSecretInVaultAuthenticator):
-
     def test_authenticate(self):
         authenticator = VaultAuthenticatorApprole("testRole", "testSecret")
         client = FakeHvacClient()
@@ -132,13 +128,16 @@ class TestSecretInVaultAuthenticatorApprole(unittest.TestCase, TestSecretInVault
 
 
 class TestSecretInHashiCorpVaultKvSecretProvider(ConfigErrorsMixin, unittest.TestCase):
-
     def setUp(self):
         if hvac is None:
-            raise unittest.SkipTest(
-                "Need to install hvac to test HashiCorpVaultKvSecretProvider")
-        param = {"vault_server": "", "authenticator": VaultAuthenticatorToken("mockToken"),
-                "path_delimiter": '|', "path_escape": '\\', "api_version": 2}
+            raise unittest.SkipTest("Need to install hvac to test HashiCorpVaultKvSecretProvider")
+        param = {
+            "vault_server": "",
+            "authenticator": VaultAuthenticatorToken("mockToken"),
+            "path_delimiter": '|',
+            "path_escape": '\\',
+            "api_version": 2,
+        }
         self.provider = HashiCorpVaultKvSecretProvider(**param)
         self.provider.reconfigService(**param)
         self.provider.client = FakeHvacClient()
@@ -147,21 +146,37 @@ class TestSecretInHashiCorpVaultKvSecretProvider(ConfigErrorsMixin, unittest.Tes
 
     @parameterized.expand([
         ('vault_server_not_string', {'vault_server': {}}, 'vault_server must be a string'),
-        ('path_delimiter_not_char', {'vault_server': 'abc', 'path_delimiter': {}},
-         'path_delimiter must be a single character'),
-        ('path_delimiter_too_long', {'vault_server': 'abc', 'path_delimiter': 'ab'},
-         'path_delimiter must be a single character'),
-        ('path_escape_not_char', {'vault_server': 'abc', 'path_escape': {}},
-         'path_escape must be a single character'),
-        ('path_escape_too_long', {'vault_server': 'abc', 'path_escape': 'ab'},
-         'path_escape must be a single character'),
-        ('api_version_unsupported', {'vault_server': 'abc', 'api_version': 3},
-         'api_version 3 is not supported'),
+        (
+            'path_delimiter_not_char',
+            {'vault_server': 'abc', 'path_delimiter': {}},
+            'path_delimiter must be a single character',
+        ),
+        (
+            'path_delimiter_too_long',
+            {'vault_server': 'abc', 'path_delimiter': 'ab'},
+            'path_delimiter must be a single character',
+        ),
+        (
+            'path_escape_not_char',
+            {'vault_server': 'abc', 'path_escape': {}},
+            'path_escape must be a single character',
+        ),
+        (
+            'path_escape_too_long',
+            {'vault_server': 'abc', 'path_escape': 'ab'},
+            'path_escape must be a single character',
+        ),
+        (
+            'api_version_unsupported',
+            {'vault_server': 'abc', 'api_version': 3},
+            'api_version 3 is not supported',
+        ),
     ])
     def test_check_config(self, name, params, error):
         with self.assertRaisesConfigError(error):
-            HashiCorpVaultKvSecretProvider(authenticator=VaultAuthenticatorToken("mockToken"),
-                                           **params)
+            HashiCorpVaultKvSecretProvider(
+                authenticator=VaultAuthenticatorToken("mockToken"), **params
+            )
 
     def test_check_config_authenticator(self):
         with self.assertRaisesConfigError('authenticator must be instance of VaultAuthenticator'):
@@ -190,8 +205,8 @@ class TestSecretInHashiCorpVaultKvSecretProvider(ConfigErrorsMixin, unittest.Tes
     @patch("hvac.Client", side_effect=mock_vault)
     def test_thd_hvac_wrap_read_unauthorized(self, mock_vault):
         self.provider.client.token = None
-        yield self.assertFailure(self.provider.thd_hvac_wrap_read("some/path"),
-                                 hvac.exceptions.Unauthorized)
+        with self.assertRaises(hvac.exceptions.Unauthorized):
+            yield self.provider.thd_hvac_wrap_read("some/path")
 
     def test_thd_hvac_get_reauthorize(self):
         """
