@@ -15,7 +15,6 @@
 
 
 from twisted.internet import defer
-from twisted.python import log
 from twisted.trial import unittest
 
 from buildbot.test.util.logging import LoggingMixin
@@ -42,7 +41,6 @@ class AsyncSort(unittest.TestCase, LoggingMixin):
     @defer.inlineCallbacks
     def test_async_fail(self):
         l = ["b", "c", "a"]
-        self.patch(log, "err", lambda f: None)
 
         class SortFail(Exception):
             pass
@@ -52,5 +50,4 @@ class AsyncSort(unittest.TestCase, LoggingMixin):
                 l, lambda x: defer.succeed(x) if x != "a" else defer.fail(SortFail("ono"))
             )
 
-        self.assertEqual(len(self.flushLoggedErrors(SortFail)), 1)
         self.assertEqual(l, ["b", "c", "a"])
