@@ -23,10 +23,8 @@ from buildbot.util import runprocess
 
 
 class TestRunprocessMixin(unittest.TestCase):
-
     def run_test_method(self, method):
         class TestCase(MasterRunProcessMixin, unittest.TestCase):
-
             def setUp(self):
                 self.setup_master_run_process()
 
@@ -49,9 +47,9 @@ class TestRunprocessMixin(unittest.TestCase):
         if not result.wasSuccessful():
             output = 'expected success'
             if result.failures:
-                output += (f'\ntest failed: {result.failures[0][1].getErrorMessage()}')
+                output += f'\ntest failed: {result.failures[0][1].getErrorMessage()}'
             if result.errors:
-                output += (f'\nerrors: {[error[1].value for error in result.errors]}')
+                output += f'\nerrors: {[error[1].value for error in result.errors]}'
             raise self.failureException(output)
 
         self.assertTrue(result.wasSuccessful())
@@ -74,13 +72,14 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assertEqual(expect, expect.stderr(b"error"))
 
     def test_run_process_one_command_only_rc(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(
-                ExpectMasterShell(["command"]).stdout(b'stdout').stderr(b'stderr'))
-            res = yield runprocess.run_process(None, ["command"],
-                                               collect_stdout=False, collect_stderr=False)
+                ExpectMasterShell(["command"]).stdout(b'stdout').stderr(b'stderr')
+            )
+            res = yield runprocess.run_process(
+                None, ["command"], collect_stdout=False, collect_stderr=False
+            )
             self.assertEqual(res, 0)
             testcase.assert_all_commands_ran()
 
@@ -88,13 +87,14 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_successful(result)
 
     def test_run_process_one_command_only_rc_stdout(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(
-                ExpectMasterShell(["command"]).stdout(b'stdout').stderr(b'stderr'))
-            res = yield runprocess.run_process(None, ["command"],
-                                               collect_stdout=True, collect_stderr=False)
+                ExpectMasterShell(["command"]).stdout(b'stdout').stderr(b'stderr')
+            )
+            res = yield runprocess.run_process(
+                None, ["command"], collect_stdout=True, collect_stderr=False
+            )
             self.assertEqual(res, (0, b'stdout'))
             testcase.assert_all_commands_ran()
 
@@ -102,13 +102,14 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_successful(result)
 
     def test_run_process_one_command_with_rc_stderr(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(
-                ExpectMasterShell(["command"]).stdout(b'stdout').stderr(b'stderr'))
-            res = yield runprocess.run_process(None, ["command"],
-                                               collect_stdout=False, collect_stderr=True)
+                ExpectMasterShell(["command"]).stdout(b'stdout').stderr(b'stderr')
+            )
+            res = yield runprocess.run_process(
+                None, ["command"], collect_stdout=False, collect_stderr=True
+            )
             self.assertEqual(res, (0, b'stderr'))
             testcase.assert_all_commands_ran()
 
@@ -116,11 +117,11 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_successful(result)
 
     def test_run_process_one_command_with_rc_stdout_stderr(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(
-                ExpectMasterShell(["command"]).stdout(b'stdout').stderr(b'stderr'))
+                ExpectMasterShell(["command"]).stdout(b'stdout').stderr(b'stderr')
+            )
             res = yield runprocess.run_process(None, ["command"])
             self.assertEqual(res, (0, b'stdout', b'stderr'))
             testcase.assert_all_commands_ran()
@@ -129,7 +130,6 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_successful(result)
 
     def test_run_process_expect_two_run_one(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(ExpectMasterShell(["command"]))
@@ -142,7 +142,6 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_test_failure(result, "assert all expected commands were run")
 
     def test_run_process_wrong_command(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(ExpectMasterShell(["command2"]))
@@ -154,7 +153,6 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_test_failure(result, "command2")
 
     def test_run_process_wrong_args(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(ExpectMasterShell(["command", "arg"]))
@@ -165,7 +163,6 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_test_failure(result, "unexpected command run")
 
     def test_run_process_missing_path(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(ExpectMasterShell(["command"]).workdir("/home"))
@@ -176,7 +173,6 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_test_failure(result, "unexpected command run")
 
     def test_run_process_wrong_path(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(ExpectMasterShell(["command", "arg"]).workdir("/home"))
@@ -187,7 +183,6 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_test_failure(result, "unexpected command run")
 
     def test_run_process_not_current_path(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(ExpectMasterShell(["command", "arg"]))
@@ -198,12 +193,12 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_test_failure(result, "unexpected command run")
 
     def test_run_process_error_output(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(ExpectMasterShell(["command"]).stderr(b"some test"))
-            res = yield runprocess.run_process(None, ["command"], collect_stderr=False,
-                                               stderr_is_error=True)
+            res = yield runprocess.run_process(
+                None, ["command"], collect_stderr=False, stderr_is_error=True
+            )
             self.assertEqual(res, (-1, b''))
             testcase.assert_all_commands_ran()
 
@@ -211,7 +206,6 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_successful(result)
 
     def test_run_process_nonzero_exit(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(ExpectMasterShell(["command"]).exit(1))
@@ -223,7 +217,6 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_successful(result)
 
     def test_run_process_environ_success(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(ExpectMasterShell(["command"]))
@@ -236,7 +229,6 @@ class TestRunprocessMixin(unittest.TestCase):
         self.assert_successful(result)
 
     def test_run_process_environ_wrong_value(self):
-
         @defer.inlineCallbacks
         def method(testcase):
             testcase.expect_commands(ExpectMasterShell(["command"]))
@@ -254,5 +246,6 @@ class TestRunprocessMixin(unittest.TestCase):
             testcase.add_run_process_expect_env({'key': 'value'})
             d = runprocess.run_process(None, ["command"])
             return d
+
         result = self.run_test_method(method)
         self.assert_test_failure(result, "Expected environment to have key = 'value'")
