@@ -25,5 +25,5 @@ class MatchTuple(tuplematching.TupleMatchingMixin, unittest.TestCase):
     def do_test_match(self, routingKey, shouldMatch, filter):
         result = tuplematch.matchTuple(routingKey, filter)
         should_match_string = 'should match' if shouldMatch else "shouldn't match"
-        msg = f"{repr(routingKey)} {should_match_string} {repr(filter)}"
+        msg = f"{routingKey!r} {should_match_string} {filter!r}"
         self.assertEqual(shouldMatch, result, msg)
