@@ -13,6 +13,7 @@
 #
 # Copyright Buildbot Team Members
 
+from pathlib import PurePath
 from unittest import mock
 
 from parameterized import parameterized
@@ -67,6 +68,12 @@ class WorkerInterfaceTests(interfaces.InterfaceTests):
         yield self.callAttached()
         self.assertTrue(hasattr(self.wrk, 'path_module'))
 
+    @defer.inlineCallbacks
+    def test_attr_path_cls(self):
+        yield self.callAttached()
+        path_cls = self.wrk.path_cls
+        self.assertTrue(issubclass(path_cls, PurePath))
+
     @defer.inlineCallbacks
     def test_attr_worker_system(self):
         yield self.callAttached()
@@ -126,6 +133,7 @@ class RealWorkerItfc(TestReactorMixin, unittest.TestCase, WorkerInterfaceTests):
         yield self.workers.setServiceParent(self.master)
         self.master.workers = self.workers
         yield self.wrk.setServiceParent(self.master.workers)
+        yield self.master.startService()
         self.conn = fakeprotocol.FakeConnection(self.wrk)
         yield self.wrk.attached(self.conn)
 
@@ -685,7 +693,9 @@ class TestAbstractWorker(logging.LoggingMixin, TestReactorMixin, unittest.TestCa
         self.assertNotEqual(worker.missing_timer, None)
         yield self.reactor.advance(1)
         self.assertEqual(worker.missing_timer, None)
-        self.assertEqual(len(self.master.data.updates.missingWorkers), 1)
+        self.assertEqual(
+            [key for key, _ in self.master.mq.productions], [('workers', '1', 'missing')]
+        )
 
     @defer.inlineCallbacks
     def test_missing_timer_stopped(self):
@@ -694,7 +704,7 @@ class TestAbstractWorker(logging.LoggingMixin, TestReactorMixin, unittest.TestCa
         self.assertNotEqual(worker.missing_timer, None)
         yield worker.stopService()
         self.assertEqual(worker.missing_timer, None)
-        self.assertEqual(len(self.master.data.updates.missingWorkers), 0)
+        self.assertEqual([key for key, _ in self.master.mq.productions], [])
 
     @defer.inlineCallbacks
     def test_worker_actions_stop(self):
