@@ -22,23 +22,18 @@ from buildbot.test.util.warnings import assertNotProducesWarnings
 from buildbot.warnings import DeprecatedApiWarning
 
 try:
-    from moto import mock_aws
-
-    assert mock_aws
     import boto3
-
-    assert boto3
     from botocore.client import ClientError
+    from moto import mock_aws
 except ImportError:
     boto3 = None
-    ec2 = None
     ClientError = None
 
 
 if boto3 is not None:
-    from buildbot.worker import ec2  # pylint: disable=ungrouped-imports
+    from buildbot.worker import ec2
 else:
-    ec2 = None
+    ec2 = None  # type: ignore[assignment]
 
 
 # Current moto (1.3.7) requires dummy credentials to work
@@ -56,7 +51,7 @@ def skip_ec2(f):
 
 
 if boto3 is None:
-    mock_aws = skip_ec2
+    mock_aws = skip_ec2  # type: ignore[assignment]
 
 
 def anyImageId(c):
@@ -91,8 +86,7 @@ class TestEC2LatentWorker(unittest.TestCase):
             r.create_key_pair(KeyName=name)
         except NotImplementedError as e:
             raise unittest.SkipTest(
-                "KeyPairs.create_key_pair not implemented"
-                " in this version of moto, please update."
+                "KeyPairs.create_key_pair not implemented in this version of moto, please update."
             ) from e
         r.create_security_group(GroupName=name, Description='the security group')
         instance = r.create_instances(ImageId=anyImageId(c), MinCount=1, MaxCount=1)[0]
@@ -605,8 +599,7 @@ class TestEC2LatentWorkerDefaultKeyairSecurityGroup(unittest.TestCase):
             r.create_key_pair(KeyName='test_keypair')
         except NotImplementedError as e:
             raise unittest.SkipTest(
-                "KeyPairs.create_key_pair not implemented"
-                " in this version of moto, please update."
+                "KeyPairs.create_key_pair not implemented in this version of moto, please update."
             ) from e
         r.create_security_group(GroupName='latent_buildbot_slave', Description='the security group')
         r.create_security_group(GroupName='test_security_group', Description='other security group')
