@@ -706,7 +706,7 @@ def _prepare_request(payload, headers=None, change_dict=None):
     return request
 
 
-class TestChangeHookConfiguredWithGitChange(unittest.TestCase, TestReactorMixin):
+class TestChangeHookConfiguredWithGitChange(TestReactorMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
@@ -921,4 +921,4 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase, TestReactorMixin)
         request.received_headers[b'Content-Type'] = b'invalid/content'
         yield request.test_render(self.change_hook)
         self.assertEqual(len(self.change_hook.master.data.updates.changesAdded), 0)
-        self.assertEqual(request.written, b"Unknown content type: invalid/content")
+        self.assertEqual(request.written, b"Unknown content type: 'invalid/content'")
