@@ -233,7 +233,7 @@ class TestBuildbotSite(unittest.SynchronousTestCase):
 
     def test_getSession_from_correct_jwt(self):
         payload = {'user_info': {'some': 'payload'}}
-        uid = jwt.encode(payload, self.SECRET, algorithm=service.SESSION_SECRET_ALGORITHM)
+        uid = jwt.encode(payload, self.SECRET, algorithm=auth.SESSION_SECRET_ALGORITHM)
         session = self.site.getSession(uid)
         self.assertEqual(session.user_info, {'some': 'payload'})
 
@@ -242,13 +242,13 @@ class TestBuildbotSite(unittest.SynchronousTestCase):
         exp = datetime.datetime.now(datetime.timezone.utc) - datetime.timedelta(weeks=1)
         exp = calendar.timegm(datetime.datetime.timetuple(exp))
         payload = {'user_info': {'some': 'payload'}, 'exp': exp}
-        uid = jwt.encode(payload, self.SECRET, algorithm=service.SESSION_SECRET_ALGORITHM)
+        uid = jwt.encode(payload, self.SECRET, algorithm=auth.SESSION_SECRET_ALGORITHM)
         with self.assertRaises(KeyError):
             self.site.getSession(uid)
 
     def test_getSession_with_no_user_info(self):
         payload = {'foo': 'bar'}
-        uid = jwt.encode(payload, self.SECRET, algorithm=service.SESSION_SECRET_ALGORITHM)
+        uid = jwt.encode(payload, self.SECRET, algorithm=auth.SESSION_SECRET_ALGORITHM)
         with self.assertRaises(KeyError):
             self.site.getSession(uid)
 
@@ -263,7 +263,7 @@ class TestBuildbotSite(unittest.SynchronousTestCase):
         session.updateSession(request)
         self.assertEqual(len(request.cookies), 1)
         _, value = request.cookies[0].split(b";")[0].split(b"=")
-        decoded = jwt.decode(value, self.SECRET, algorithms=[service.SESSION_SECRET_ALGORITHM])
+        decoded = jwt.decode(value, self.SECRET, algorithms=[auth.SESSION_SECRET_ALGORITHM])
         self.assertEqual(decoded['user_info'], {'anonymous': True})
         self.assertIn('exp', decoded)
 
