@@ -18,6 +18,8 @@ import os
 import re
 import sys
 from io import StringIO
+from typing import TYPE_CHECKING
+from typing import Any
 from unittest import mock
 
 from twisted.internet import defer
@@ -41,12 +43,10 @@ from buildbot.test.util.sandboxed_worker import SandboxedWorker
 from buildbot.util.twisted import any_to_async
 from buildbot.util.twisted import async_to_deferred
 from buildbot.worker.local import LocalWorker
+from buildbot_worker.bot import Worker
 
-Worker: type | None = None
-try:
-    from buildbot_worker.bot import Worker
-except ImportError:
-    pass
+if TYPE_CHECKING:
+    from twisted.application.service import Service
 
 
 @implementer(IConfigLoader)
@@ -59,7 +59,7 @@ class DictLoader:
 
 
 class TestedMaster:
-    def __init__(self):
+    def __init__(self) -> None:
         self.master: BuildMaster | None = None
         self.is_master_shutdown = False
 
@@ -79,7 +79,7 @@ class TestedMaster:
 
         # TODO: Allow BuildMaster to transparently upgrade the database, at least
         # for tests.
-        self.master.config.db['db_url'] = config_dict['db_url']
+        self.master.config.db.db_url = config_dict['db_url']
         await self.master.db.setup(check_version=False)
         await self.master.db.model.upgrade()
         self.master.db.setup = lambda: None
@@ -174,7 +174,7 @@ async def print_build(build, master: BuildMaster, out=sys.stdout, with_logs=Fals
                 print_test_log(l, out)
 
 
-class RunFakeMasterTestCase(unittest.TestCase, TestReactorMixin, DebugIntegrationLogsMixin):
+class RunFakeMasterTestCase(TestReactorMixin, DebugIntegrationLogsMixin, unittest.TestCase):
     def setUp(self):
         self.setup_test_reactor()
         self.setupDebugIntegrationLogs()
@@ -274,10 +274,10 @@ class RunFakeMasterTestCase(unittest.TestCase, TestReactorMixin, DebugIntegratio
 
 
 class TestedRealMaster(TestedMaster):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.case: unittest.TestCase | None = None
-        self.worker: Worker | None = None
+        self.worker: Service | None = None
 
     @async_to_deferred
     async def setup_master(
@@ -301,6 +301,7 @@ class TestedRealMaster(TestedMaster):
         case.patch(reactor, 'stop', stop)
 
         if start_worker:
+            config_protocols: dict[str, Any] = {}
             if proto == 'pb':
                 config_protocols = {"pb": {"port": "tcp:0:interface=127.0.0.1"}}
                 workerclass = worker.Worker
@@ -324,6 +325,7 @@ class TestedRealMaster(TestedMaster):
         if not start_worker:
             return
 
+        assert self.master
         if proto in ('pb', 'msgpack'):
             sandboxed_worker_path = os.environ.get("SANDBOXED_WORKER_PATH", None)
             if proto == 'pb':
@@ -401,9 +403,6 @@ class RunMasterBase(unittest.TestCase):
     # oversubscribed hosts.
     timeout = 60
 
-    if Worker is None:
-        skip = "buildbot-worker package is not installed"
-
     @defer.inlineCallbacks
     def setup_master(self, config_dict, startWorker=True, basedir=None, **worker_kwargs):
         self.tested_master = TestedRealMaster()
