@@ -13,23 +13,27 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
 
 import os
+from typing import TYPE_CHECKING
 
 import sqlalchemy as sa
+from alembic.operations import Operations
 from alembic.runtime.migration import MigrationContext
-
 from twisted.internet import defer
 from twisted.python import log
 
-from buildbot.db import connector
 from buildbot.test.fake import fakemaster
 from buildbot.test.reactor import TestReactorMixin
-from buildbot.test.util import db
 from buildbot.test.util import dirs
 from buildbot.test.util import querylog
 from buildbot.util import sautils
 
+if TYPE_CHECKING:
+    from sqlalchemy.future.engine import Connection
+
+
 # test_upgrade vs. migration tests
 #
 # test_upgrade is an integration test -- it tests the whole upgrade process,
@@ -37,46 +41,39 @@ from buildbot.util import sautils
 # single db upgrade script.
 
 
-class MigrateTestMixin(TestReactorMixin, db.RealDatabaseMixin, dirs.DirsMixin):
-
+class MigrateTestMixin(TestReactorMixin, dirs.DirsMixin):
     @defer.inlineCallbacks
     def setUpMigrateTest(self):
         self.setup_test_reactor()
         self.basedir = os.path.abspath("basedir")
         self.setUpDirs('basedir')
 
-        yield self.setUpRealDatabase()
-
-        master = fakemaster.make_master(self)
-        self.db = connector.DBConnector(self.basedir)
-        yield self.db.setServiceParent(master)
-        self.db.pool = self.db_pool
-
-    def tearDownMigrateTest(self):
-        self.tearDownDirs()
-        return self.tearDownRealDatabase()
+        self.master = yield fakemaster.make_master(
+            self, wantDb=True, auto_upgrade=False, check_version=False
+        )
 
     @defer.inlineCallbacks
-    def do_test_migration(self, base_revision, target_revision,
-                          setup_thd_cb, verify_thd_cb):
-
+    def do_test_migration(self, base_revision, target_revision, setup_thd_cb, verify_thd_cb):
         def setup_thd(conn):
             metadata = sa.MetaData()
             table = sautils.Table(
-                'alembic_version', metadata,
+                'alembic_version',
+                metadata,
                 sa.Column("version_num", sa.String(32), nullable=False),
             )
             table.create(bind=conn)
-            conn.execute(table.insert(), version_num=base_revision)
+            conn.execute(table.insert().values(version_num=base_revision))
+            conn.commit()
             setup_thd_cb(conn)
-        yield self.db.pool.do(setup_thd)
 
-        alembic_scripts = self.alembic_get_scripts()
+        yield self.master.db.pool.do(setup_thd)
+
+        alembic_scripts = self.master.db.model.alembic_get_scripts()
 
         def upgrade_thd(engine):
             with querylog.log_queries():
-                with sautils.withoutSqliteForeignKeys(engine):
-                    with engine.connect() as conn:
+                with engine.connect() as conn:
+                    with sautils.withoutSqliteForeignKeys(conn):
 
                         def upgrade(rev, context):
                             log.msg(f'Upgrading from {rev} to {target_revision}')
@@ -84,25 +81,36 @@ class MigrateTestMixin(TestReactorMixin, db.RealDatabaseMixin, dirs.DirsMixin):
 
                         context = MigrationContext.configure(conn, opts={'fn': upgrade})
 
-                        with context.begin_transaction():
-                            context.run_migrations()
+                        with Operations.context(context):
+                            with context.begin_transaction():
+                                context.run_migrations()
 
-        yield self.db.pool.do_with_engine(upgrade_thd)
+                        conn.commit()
 
-        def check_table_charsets_thd(engine):
+        yield self.master.db.pool.do_with_engine(upgrade_thd)
+
+        def check_table_charsets_thd(conn: Connection):
             # charsets are only a problem for MySQL
-            if engine.dialect.name != 'mysql':
+            if conn.dialect.name != 'mysql':
                 return
-            dbs = [r[0] for r in engine.execute("show tables")]
+
+            dbs = [r[0] for r in conn.exec_driver_sql("show tables")]
             for tbl in dbs:
-                r = engine.execute(f"show create table {tbl}")
-                create_table = r.fetchone()[1]
-                self.assertIn('DEFAULT CHARSET=utf8', create_table,
-                              f"table {tbl} does not have the utf8 charset")
-        yield self.db.pool.do(check_table_charsets_thd)
+                r = conn.exec_driver_sql(f"show create table {tbl}")
+                assert r is not None
+                res = r.fetchone()
+                assert res is not None
+                create_table = res[1]
+                self.assertIn(  # type: ignore[attr-defined]
+                    'DEFAULT CHARSET=utf8',
+                    create_table,
+                    f"table {tbl} does not have the utf8 charset",
+                )
 
-        def verify_thd(engine):
-            with sautils.withoutSqliteForeignKeys(engine):
-                verify_thd_cb(engine)
+        yield self.master.db.pool.do(check_table_charsets_thd)
 
-        yield self.db.pool.do(verify_thd)
+        def verify_thd(conn):
+            with sautils.withoutSqliteForeignKeys(conn):
+                verify_thd_cb(conn)
+
+        yield self.master.db.pool.do(verify_thd)
