@@ -467,10 +467,8 @@ def command_to_string(command):
 
     try:
         len(words)
-    except (AttributeError, TypeError):
+    except TypeError:
         # WithProperties and Property don't have __len__
-        # For old-style classes instances AttributeError raised,
-        # for new-style classes instances - TypeError.
         return None
 
     # flatten any nested lists
@@ -545,22 +543,22 @@ def dictionary_merge(a, b):
 
 
 __all__ = [
-    'naturalSort',
-    'now',
-    'formatInterval',
-    'ComparableMixin',
-    'safeTranslate',
-    'none_or_str',
-    'NotABranch',
-    'deferredLocked',
     'UTC',
-    'diffSets',
-    'makeList',
-    'in_reactor',
-    'string2boolean',
-    'check_functional_environment',
-    'human_readable_delta',
-    'rewrap',
+    'ComparableMixin',
+    'NotABranch',
     'Notifier',
+    'check_functional_environment',
+    'deferredLocked',
+    'diffSets',
+    'formatInterval',
     "giturlparse",
+    'human_readable_delta',
+    'in_reactor',
+    'makeList',
+    'naturalSort',
+    'none_or_str',
+    'now',
+    'rewrap',
+    'safeTranslate',
+    'string2boolean',
 ]
