@@ -19,6 +19,7 @@ import os
 import re
 import stat
 from pathlib import Path
+from pathlib import PurePath
 from typing import TYPE_CHECKING
 from typing import ClassVar
 from typing import Sequence
@@ -34,13 +35,13 @@ from buildbot.process.properties import Properties
 from buildbot.steps.worker import CompositeStepMixin
 from buildbot.util import ComparableMixin
 from buildbot.util import bytes2unicode
-from buildbot.util.git_credential import GitCredentialOptions
 from buildbot.util.misc import writeLocalFile
 from buildbot.util.twisted import async_to_deferred
 
 if TYPE_CHECKING:
     from buildbot.changes.gitpoller import GitPoller
     from buildbot.interfaces import IRenderable
+    from buildbot.util.git_credential import GitCredentialOptions
 
 RC_SUCCESS = 0
 
@@ -76,9 +77,9 @@ def scp_style_to_url_syntax(address, port=22, scheme='ssh'):
 
 def check_ssh_config(
     logname: str,
-    ssh_private_key: IRenderable | None,
-    ssh_host_key: IRenderable | None,
-    ssh_known_hosts: IRenderable | None,
+    ssh_private_key: IRenderable | str | None,
+    ssh_host_key: IRenderable | str | None,
+    ssh_known_hosts: IRenderable | str | None,
 ):
     if ssh_host_key is not None and ssh_private_key is None:
         config.error(f'{logname}: sshPrivateKey must be provided in order use sshHostKey')
@@ -190,9 +191,9 @@ class GitStepMixin(GitMixin):
 
     def setup_git_auth(
         self,
-        ssh_private_key: IRenderable | None,
-        ssh_host_key: IRenderable | None,
-        ssh_known_hosts: IRenderable | None,
+        ssh_private_key: IRenderable | str | None,
+        ssh_host_key: IRenderable | str | None,
+        ssh_known_hosts: IRenderable | str | None,
         git_credential_options: GitCredentialOptions | None = None,
     ) -> None:
         self._git_auth = GitStepAuth(
@@ -291,9 +292,9 @@ class AbstractGitAuth(ComparableMixin):
 
     def __init__(
         self,
-        ssh_private_key: IRenderable | None = None,
-        ssh_host_key: IRenderable | None = None,
-        ssh_known_hosts: IRenderable | None = None,
+        ssh_private_key: IRenderable | str | None = None,
+        ssh_host_key: IRenderable | str | None = None,
+        ssh_known_hosts: IRenderable | str | None = None,
         git_credential_options: GitCredentialOptions | None = None,
     ) -> None:
         self.did_download_auth_files = False
@@ -320,6 +321,7 @@ class AbstractGitAuth(ComparableMixin):
         git_commands_that_need_auth = [
             'clone',
             'credential',
+            'checkout',
             'fetch',
             'ls-remote',
             'push',
@@ -557,9 +559,9 @@ class GitStepAuth(AbstractGitAuth):
         self,
         # step must implement all these types
         step: buildstep.BuildStep | GitStepMixin | CompositeStepMixin,
-        ssh_private_key: IRenderable | None = None,
-        ssh_host_key: IRenderable | None = None,
-        ssh_known_hosts: IRenderable | None = None,
+        ssh_private_key: IRenderable | str | None = None,
+        ssh_host_key: IRenderable | str | None = None,
+        ssh_known_hosts: IRenderable | str | None = None,
         git_credential_options: GitCredentialOptions | None = None,
     ) -> None:
         self.step = step
@@ -618,12 +620,17 @@ class GitStepAuth(AbstractGitAuth):
         assert isinstance(self.step, buildstep.BuildStep) and self.step.build is not None
         return self.step.build.path_module
 
+    @property
+    def _path_cls(self) -> type[PurePath]:
+        assert isinstance(self.step, buildstep.BuildStep) and self.step.build is not None
+        assert self.step.build.path_cls is not None
+        return self.step.build.path_cls
+
     @property
     def _master(self):
         assert isinstance(self.step, buildstep.BuildStep) and self.step.master is not None
         return self.step.master
 
-    @async_to_deferred
     async def _download_file(
         self,
         path: str,
@@ -688,9 +695,9 @@ class GitServiceAuth(AbstractGitAuth):
     def __init__(
         self,
         service: GitPoller,
-        ssh_private_key: IRenderable | None = None,
-        ssh_host_key: IRenderable | None = None,
-        ssh_known_hosts: IRenderable | None = None,
+        ssh_private_key: IRenderable | str | None = None,
+        ssh_host_key: IRenderable | str | None = None,
+        ssh_known_hosts: IRenderable | str | None = None,
         git_credential_options: GitCredentialOptions | None = None,
     ) -> None:
         self._service = service
@@ -721,7 +728,6 @@ class GitServiceAuth(AbstractGitAuth):
             auth_files_path=workdir,  # this is ... not great
         )
 
-    @async_to_deferred
     async def _download_file(
         self,
         path: str,
