@@ -12,6 +12,7 @@
 # Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # Copyright Buildbot Team Members
+from __future__ import annotations
 
 from twisted.internet import defer
 
@@ -27,30 +28,31 @@ class Listener:
 class UpdateRegistrationListener(Listener):
     def __init__(self):
         super().__init__()
-        # username : (password, portstr, PBManager registration)
+        # username : (password, portstr, manager registration)
         self._registrations = {}
 
     @defer.inlineCallbacks
     def updateRegistration(self, username, password, portStr):
-        # NOTE: this method is only present on the PB protocol; others do not
+        # NOTE: this method is only present on the PB and MsgPack protocols; others do not
         # use registrations
         if username in self._registrations:
-            currentPassword, currentPortStr, currentReg = \
-                self._registrations[username]
+            currentPassword, currentPortStr, currentReg = self._registrations[username]
         else:
             currentPassword, currentPortStr, currentReg = None, None, None
 
-        iseq = (ComparableMixin.isEquivalent(currentPassword, password) and
-                ComparableMixin.isEquivalent(currentPortStr, portStr))
+        iseq = ComparableMixin.isEquivalent(
+            currentPassword, password
+        ) and ComparableMixin.isEquivalent(currentPortStr, portStr)
         if iseq:
             return currentReg
         if currentReg:
             yield currentReg.unregister()
             del self._registrations[username]
 
-        if portStr and password:
-            reg = yield self.get_manager().register(portStr, username, password,
-                                                    self._create_connection)
+        if portStr is not None and password:
+            reg = yield self.get_manager().register(
+                portStr, username, password, self._create_connection
+            )
             self._registrations[username] = (password, portStr, reg)
             return reg
         return currentReg
@@ -73,10 +75,10 @@ class UpdateRegistrationListener(Listener):
 
 
 class Connection:
-    proxies = {}
+    proxies: dict[type, type] = {}
 
     def __init__(self, name):
-        self._disconnectSubs = subscription.SubscriptionPoint("disconnections from {}".format(name))
+        self._disconnectSubs = subscription.SubscriptionPoint(f"disconnections from {name}")
 
     # This method replace all Impl args by their Proxy protocol implementation
     def createArgsProxies(self, args):
@@ -88,6 +90,9 @@ class Connection:
             newargs[k] = v
         return newargs
 
+    def get_peer(self):
+        raise NotImplementedError
+
     # disconnection handling
 
     def wait_shutdown_started(self):
@@ -133,7 +138,6 @@ class Connection:
 
 # RemoteCommand base implementation and base proxy
 class RemoteCommandImpl:
-
     def remote_update(self, updates):
         raise NotImplementedError
 
@@ -143,7 +147,6 @@ class RemoteCommandImpl:
 
 # FileWriter base implementation
 class FileWriterImpl:
-
     def remote_write(self, data):
         raise NotImplementedError
 
@@ -159,7 +162,6 @@ class FileWriterImpl:
 
 # FileReader base implementation
 class FileReaderImpl:
-
     def remote_read(self, maxLength):
         raise NotImplementedError
 
