@@ -14,14 +14,18 @@
 # Copyright Buildbot Team Members
 
 
+from __future__ import annotations
+
 import hmac
 import json
 import logging
 import re
 from hashlib import sha1
+from typing import TYPE_CHECKING
+from typing import Any
+from typing import Callable
 
 from dateutil.parser import parse as dateparse
-
 from twisted.internet import defer
 from twisted.python import log
 
@@ -32,27 +36,37 @@ from buildbot.util import unicode2bytes
 from buildbot.util.pullrequest import PullRequestMixin
 from buildbot.www.hooks.base import BaseHookHandler
 
+if TYPE_CHECKING:
+    from twisted.internet.defer import Deferred
+    from twisted.web.server import Request
+
+    from buildbot.master import BuildMaster
+    from buildbot.util.twisted import InlineCallbacksType
+
 _HEADER_EVENT = b'X-GitHub-Event'
 _HEADER_SIGNATURE = b'X-Hub-Signature'
 
-DEFAULT_SKIPS_PATTERN = (r'\[ *skip *ci *\]', r'\[ *ci *skip *\]')
+DEFAULT_SKIPS_PATTERN: list[str] = [r'\[ *skip *ci *\]', r'\[ *ci *skip *\]']
 DEFAULT_GITHUB_API_URL = 'https://api.github.com'
 
 
 class GitHubEventHandler(PullRequestMixin):
-
     property_basename = "github"
 
-    def __init__(self, secret, strict,
-                 codebase=None,
-                 github_property_whitelist=None,
-                 master=None,
-                 skips=None,
-                 github_api_endpoint=None,
-                 pullrequest_ref=None,
-                 token=None,
-                 debug=False,
-                 verify=False):
+    def __init__(
+        self,
+        secret: str | None,
+        strict: bool,
+        codebase: str | Callable | None = None,
+        github_property_whitelist: list[str] | None = None,
+        master: BuildMaster | None = None,
+        skips: list[str] | None = None,
+        github_api_endpoint: str | None = None,
+        pullrequest_ref: str | None = None,
+        token: str | None = None,
+        debug: bool = False,
+        verify: bool = True,
+    ):
         if github_property_whitelist is None:
             github_property_whitelist = []
         self._secret = secret
@@ -70,17 +84,15 @@ class GitHubEventHandler(PullRequestMixin):
             self.github_api_endpoint = DEFAULT_GITHUB_API_URL
 
         if self._strict and not self._secret:
-            raise ValueError('Strict mode is requested '
-                             'while no secret is provided')
+            raise ValueError('Strict mode is requested while no secret is provided')
         self.debug = debug
         self.verify = verify
 
     @defer.inlineCallbacks
-    def process(self, request):
+    def process(self, request: Request) -> InlineCallbacksType[tuple[list[dict[str, Any]], str]]:
         payload = yield self._get_payload(request)
 
-        event_type = request.getHeader(_HEADER_EVENT)
-        event_type = bytes2unicode(event_type)
+        event_type = bytes2unicode(request.getHeader(_HEADER_EVENT))
         log.msg(f"X-GitHub-Event: {event_type}", logLevel=logging.DEBUG)
 
         handler = getattr(self, f'handle_{event_type}', None)
@@ -92,12 +104,11 @@ class GitHubEventHandler(PullRequestMixin):
         return result
 
     @defer.inlineCallbacks
-    def _get_payload(self, request):
-        content = request.content.read()
-        content = bytes2unicode(content)
+    def _get_payload(self, request: Request) -> InlineCallbacksType[dict[str, Any]]:
+        assert request.content is not None
 
-        signature = request.getHeader(_HEADER_SIGNATURE)
-        signature = bytes2unicode(signature)
+        content = bytes2unicode(request.content.read())
+        signature = bytes2unicode(request.getHeader(_HEADER_SIGNATURE))
 
         if not signature and self._strict:
             raise ValueError('Request has no required signature')
@@ -115,11 +126,11 @@ class GitHubEventHandler(PullRequestMixin):
             p.master = self.master
             rendered_secret = yield p.render(self._secret)
 
-            mac = hmac.new(unicode2bytes(rendered_secret),
-                           msg=unicode2bytes(content),
-                           digestmod=sha1)
+            mac = hmac.new(
+                unicode2bytes(rendered_secret), msg=unicode2bytes(content), digestmod=sha1
+            )
 
-            def _cmp(a, b):
+            def _cmp(a: str, b: str) -> bool:
                 return hmac.compare_digest(a, b)
 
             if not _cmp(bytes2unicode(mac.hexdigest()), hexdigest):
@@ -138,15 +149,15 @@ class GitHubEventHandler(PullRequestMixin):
 
         return payload
 
-    def handle_ping(self, _, __):
+    def handle_ping(self, _: dict[str, Any], __: str) -> tuple[list[dict[str, Any]], str]:
         return [], 'git'
 
-    def handle_workflow_run(self, _, __):
+    def handle_workflow_run(self, _: dict[str, Any], __: str) -> tuple[list[dict[str, Any]], str]:
         return [], 'git'
 
-    def handle_push(self, payload, event):
+    def handle_push(self, payload: dict[str, Any], event: str) -> tuple[list[dict[str, Any]], str]:
         # This field is unused:
-        user = None
+        user: str | None = None
         # user = payload['pusher']['name']
         repo = payload['repository']['name']
         repo_url = payload['repository']['html_url']
@@ -156,16 +167,17 @@ class GitHubEventHandler(PullRequestMixin):
 
         # Inject some additional white-listed event payload properties
         properties = self.extractProperties(payload)
-        changes = self._process_change(payload, user, repo, repo_url, project,
-                                       event, properties)
+        changes = self._process_change(payload, user, repo, repo_url, project, event, properties)
 
         log.msg(f"Received {len(changes)} changes from github")
 
         return changes, 'git'
 
     @defer.inlineCallbacks
-    def handle_pull_request(self, payload, event):
-        changes = []
+    def handle_pull_request(
+        self, payload: dict[str, Any], event: str
+    ) -> InlineCallbacksType[tuple[list[dict[str, Any]], str]]:
+        changes: list[dict[str, Any]] = []
         number = payload['number']
         refname = f'refs/pull/{number}/{self.pullrequest_ref}'
         basename = payload['pull_request']['base']['ref']
@@ -207,8 +219,10 @@ class GitHubEventHandler(PullRequestMixin):
             'category': 'pull',
             # TODO: Get author name based on login id using txgithub module
             'author': payload['sender']['login'],
-            'comments': (f"GitHub Pull Request #{number} ({commits} "
-                        f"commit{'s' if commits != 1 else ''})\n{title}\n{comments}"),
+            'comments': (
+                f"GitHub Pull Request #{number} ({commits} "
+                f"commit{'s' if commits != 1 else ''})\n{title}\n{comments}"
+            ),
             'properties': properties,
         }
 
@@ -223,11 +237,12 @@ class GitHubEventHandler(PullRequestMixin):
         return (changes, 'git')
 
     @defer.inlineCallbacks
-    def _get_commit_msg(self, repo, sha):
-        '''
+    def _get_commit_msg(self, repo: str, sha: str) -> InlineCallbacksType[str]:
+        """
         :param repo: the repo full name, ``{owner}/{project}``.
             e.g. ``buildbot/buildbot``
-        '''
+        """
+        assert self.master is not None
 
         headers = {
             'User-Agent': 'Buildbot',
@@ -235,13 +250,18 @@ class GitHubEventHandler(PullRequestMixin):
         if self._token:
             p = Properties()
             p.master = self.master
+            p.setProperty("full_name", repo, "change_hook")
             token = yield p.render(self._token)
             headers['Authorization'] = 'token ' + token
 
         url = f'/repos/{repo}/commits/{sha}'
-        http = yield httpclientservice.HTTPClientService.getService(
-            self.master, self.github_api_endpoint, headers=headers,
-            debug=self.debug, verify=self.verify)
+        http = yield httpclientservice.HTTPSession(
+            self.master.httpservice,
+            self.github_api_endpoint,
+            headers=headers,
+            debug=self.debug,
+            verify=self.verify,
+        )
         res = yield http.get(url)
         if 200 <= res.code < 300:
             data = yield res.json()
@@ -251,23 +271,26 @@ class GitHubEventHandler(PullRequestMixin):
         return 'No message field'
 
     @defer.inlineCallbacks
-    def _get_pr_files(self, repo, number):
+    def _get_pr_files(self, repo: str, number: int) -> InlineCallbacksType[list[str]]:
         """
         Get Files that belong to the Pull Request
         :param repo: the repo full name, ``{owner}/{project}``.
             e.g. ``buildbot/buildbot``
         :param number: the pull request number.
         """
+        assert self.master is not None
+
         headers = {"User-Agent": "Buildbot"}
         if self._token:
             p = Properties()
             p.master = self.master
+            p.setProperty("full_name", repo, "change_hook")
             token = yield p.render(self._token)
             headers["Authorization"] = "token " + token
 
         url = f"/repos/{repo}/pulls/{number}/files"
-        http = yield httpclientservice.HTTPClientService.getService(
-            self.master,
+        http = yield httpclientservice.HTTPSession(
+            self.master.httpservice,
             self.github_api_endpoint,
             headers=headers,
             debug=self.debug,
@@ -289,8 +312,16 @@ class GitHubEventHandler(PullRequestMixin):
         log.msg(f'Failed fetching PR files: response code {res.code}')
         return []
 
-    def _process_change(self, payload, user, repo, repo_url, project, event,
-                        properties):
+    def _process_change(
+        self,
+        payload: dict[str, Any],
+        user: str | None,
+        repo: str,
+        repo_url: str,
+        project: str,
+        event: str,
+        properties: dict[str, Any],
+    ) -> list[dict[str, Any]]:
         """
         Consumes the JSON as a python object and actually starts the build.
 
@@ -299,7 +330,7 @@ class GitHubEventHandler(PullRequestMixin):
                 Python Object that represents the JSON sent by GitHub Service
                 Hook.
         """
-        changes = []
+        changes: list[dict[str, Any]] = []
         refname = payload['ref']
 
         # We only care about regular heads or tags
@@ -347,7 +378,7 @@ class GitHubEventHandler(PullRequestMixin):
                     'github_distinct': commit.get('distinct', True),
                     'event': event,
                 },
-                'category': category
+                'category': category,
             }
             # Update with any white-listed github event properties
             change['properties'].update(properties)
@@ -361,27 +392,29 @@ class GitHubEventHandler(PullRequestMixin):
 
         return changes
 
-    def _has_skip(self, msg):
-        '''
+    def _has_skip(self, msg: str) -> bool:
+        """
         The message contains the skipping keyword or not.
 
         :return type: Bool
-        '''
-        for skip in self.skips:
+        """
+        skips = self.skips or []
+        for skip in skips:
             if re.search(skip, msg):
                 return True
         return False
 
+
 # for GitHub, we do another level of indirection because
 # we already had documented API that encouraged people to subclass GitHubEventHandler
 # so we need to be careful not breaking that API.
 
 
 class GitHubHandler(BaseHookHandler):
-    def __init__(self, master, options):
+    def __init__(self, master: BuildMaster, options: dict[str, Any] | None):
         if options is None:
             options = {}
-        super().__init__(master, options)
+        super().__init__(master, options)  # type: ignore[arg-type]
 
         klass = options.get('class', GitHubEventHandler)
         klass_kwargs = {
@@ -389,19 +422,17 @@ class GitHubHandler(BaseHookHandler):
             'codebase': options.get('codebase', None),
             'github_property_whitelist': options.get('github_property_whitelist', None),
             'skips': options.get('skips', None),
-            'github_api_endpoint':
-                options.get('github_api_endpoint', None) or 'https://api.github.com',
+            'github_api_endpoint': options.get('github_api_endpoint', None)
+            or 'https://api.github.com',
             'pullrequest_ref': options.get('pullrequest_ref', None) or 'merge',
             'token': options.get('token', None),
             'debug': options.get('debug', None) or False,
-            'verify': options.get('verify', None) or False,
+            'verify': options.get('verify', None) or True,
         }
-        handler = klass(options.get('secret', None),
-                        options.get('strict', False),
-                        **klass_kwargs)
+        handler = klass(options.get('secret', None), options.get('strict', False), **klass_kwargs)
         self.handler = handler
 
-    def getChanges(self, request):
+    def getChanges(self, request: Request) -> Deferred[tuple[list[dict[str, Any]], str]]:  # type: ignore[override]
         return self.handler.process(request)
 
 
