@@ -130,7 +130,6 @@ setup_args = {
         'Topic :: Software Development :: Build Tools',
         'Topic :: Software Development :: Testing',
         'Programming Language :: Python :: 3',
-        'Programming Language :: Python :: 3.8',
         'Programming Language :: Python :: 3.9',
         'Programming Language :: Python :: 3.10',
         'Programming Language :: Python :: 3.11',
@@ -497,6 +496,12 @@ setup_args = {
                             'enforceChosenWorker',
                         ],
                     ),
+                    (
+                        'buildbot.process.codebase',
+                        [
+                            'Codebase',
+                        ],
+                    ),
                     (
                         'buildbot.process.factory',
                         [
