@@ -28,15 +28,27 @@ class BuildbotWWWPkg(unittest.TestCase):
     pkgPaths = ["www", "base"]
     epName = "base"
 
-    loadTestScript = dedent("""
+    loadTestScript = dedent(r"""
         from importlib.metadata import entry_points
         import re
         apps = {}
-        for ep in entry_points().get('buildbot.www', []):
+
+        eps = entry_points()
+        entry_point = "buildbot.www"
+        if hasattr(eps, "select"):
+            entry_point_group = eps.select(group=entry_point)
+        else:
+            entry_point_group = eps.get(entry_point, [])
+
+        for ep in entry_point_group:
             apps[ep.name] = ep.load()
 
         print(apps["%(epName)s"])
-        assert("scripts.js" in apps["%(epName)s"].resource.listNames())
+        print(apps["%(epName)s"].resource.listNames())
+        expected_file = "scripts.js"
+        if "%(epName)s" == "base":
+            expected_file = "index.html"
+        assert(expected_file in apps["%(epName)s"].resource.listNames())
         assert(re.match(r'\d+\.\d+\.\d+', apps["%(epName)s"].version) is not None)
         assert(apps["%(epName)s"].description is not None)
         """)
@@ -55,35 +67,26 @@ class BuildbotWWWPkg(unittest.TestCase):
         self.rmtree(os.path.join(self.path, "dist"))
         self.rmtree(os.path.join(self.path, "static"))
 
-    def run_setup(self, cmd):
-        check_call([sys.executable, 'setup.py', cmd], cwd=self.path)
+    def run_build(self, kind):
+        check_call([sys.executable, "-m", "build", "--no-isolation", f"--{kind}"], cwd=self.path)
 
     def check_correct_installation(self):
         # assert we can import buildbot_www
-        # and that it has an endpoint with resource containing file "script.js"
-        check_call([
-            sys.executable, '-c', self.loadTestScript % dict(epName=self.epName)])
-
-    def test_install(self):
-        self.run_setup("install")
-        self.check_correct_installation()
+        # and that it has an endpoint with resource containing file "index.html"
+        check_call([sys.executable, '-c', self.loadTestScript % dict(epName=self.epName)])
 
     def test_wheel(self):
-        self.run_setup("bdist_wheel")
-        check_call("pip install dist/*.whl", shell=True, cwd=self.path)
-        self.check_correct_installation()
-
-    def test_develop(self):
-        self.run_setup("develop")
+        self.run_build("wheel")
+        check_call("pip install build dist/*.whl", shell=True, cwd=self.path)
         self.check_correct_installation()
 
     def test_develop_via_pip(self):
-        check_call("pip install -e .", shell=True, cwd=self.path)
+        check_call("pip install build -e .", shell=True, cwd=self.path)
         self.check_correct_installation()
 
     def test_sdist(self):
-        self.run_setup("sdist")
-        check_call("pip install dist/*.tar.gz", shell=True, cwd=self.path)
+        self.run_build("sdist")
+        check_call("pip install build dist/*.tar.gz", shell=True, cwd=self.path)
         self.check_correct_installation()
 
 
@@ -97,9 +100,3 @@ class BuildbotWaterfallPkg(BuildbotWWWPkg):
     pkgName = "buildbot-waterfall-view"
     pkgPaths = ["www", "waterfall_view"]
     epName = "waterfall_view"
-
-
-class BuildbotCodeparameterPkg(BuildbotWWWPkg):
-    pkgName = "buildbot-codeparameter"
-    pkgPaths = ["www", "codeparameter"]
-    epName = "codeparameter"
