@@ -14,6 +14,5 @@
 # Copyright Buildbot Team Members
 
 
-def patch_all():
-    from buildbot_worker.monkeypatches import testcase_assert
-    testcase_assert.patch()
+def patch_all() -> None:
+    pass
