@@ -15,19 +15,15 @@
 
 from __future__ import annotations
 
-import sys
 from typing import Any
 
-import twisted
-from twisted.trial import unittest
-
 from buildbot_worker import monkeypatches
 
 # apply the same patches the worker does when it starts
 monkeypatches.patch_all()
 
 
-def add_debugging_monkeypatches():
+def add_debugging_monkeypatches() -> None:
     """
     DO NOT CALL THIS DIRECTLY
 
@@ -39,25 +35,16 @@ def add_debugging_monkeypatches():
     old_startService = Service.startService
     old_stopService = Service.stopService
 
-    def startService(self):
+    def startService(self: Service) -> None:
         assert not self.running
         return old_startService(self)
 
-    def stopService(self):
+    def stopService(self: Service) -> None:
         assert self.running
         return old_stopService(self)
 
-    Service.startService = startService
-    Service.stopService = stopService
-
-    # versions of Twisted before 9.0.0 did not have a UnitTest.patch that worked
-    # on Python-2.7
-    if twisted.version.major <= 9 and sys.version_info[:2] == (2, 7):
-
-        def nopatch(self, *args):
-            raise unittest.SkipTest('unittest.TestCase.patch is not available')
-
-        unittest.TestCase.patch = nopatch
+    Service.startService = startService  # type: ignore[method-assign]
+    Service.stopService = stopService  # type: ignore[method-assign]
 
 
 add_debugging_monkeypatches()
