@@ -35,7 +35,7 @@ from buildbot_worker.test.util import command
 try:
     from unittest import mock
 except ImportError:
-    import mock
+    from unittest import mock
 
 
 class TestBot(unittest.TestCase):
@@ -46,7 +46,7 @@ class TestBot(unittest.TestCase):
         os.makedirs(self.basedir)
 
         # create test-release-file
-        with open("{}/test-release-file".format(self.basedir), "w") as fout:
+        with open(f"{self.basedir}/test-release-file", "w") as fout:
             fout.write("""
 # unit test release file
 OS_NAME="Test"
@@ -57,15 +57,13 @@ PRETTY_NAME="Test 1.0 Generic"
 VERSION_ID="1"
 """)
         self.real_bot = pb.BotPbLike(self.basedir, False)
-        self.real_bot.setOsReleaseFile("{}/test-release-file".format(self.basedir))
+        self.real_bot.setOsReleaseFile(f"{self.basedir}/test-release-file")
         self.real_bot.startService()
+        self.addCleanup(self.real_bot.stopService)
 
         self.bot = FakeRemote(self.real_bot)
 
-    @defer.inlineCallbacks
     def tearDown(self):
-        if self.real_bot and self.real_bot.running:
-            yield self.real_bot.stopService()
         if os.path.exists(self.basedir):
             shutil.rmtree(self.basedir)
 
@@ -176,10 +174,10 @@ VERSION_ID="1"
         d2 = self.bot.callRemote("shutdown")
         # don't return until both the shutdown method has returned, and
         # reactor.stop has been called
-        return defer.gatherResults([d1, d2])
+        return defer.gatherResults([d1, d2], consumeErrors=True)
 
 
-class FakeStep(object):
+class FakeStep:
     "A fake master-side BuildStep that records its activities."
 
     def __init__(self):
@@ -214,6 +212,7 @@ class TestWorkerForBuilder(command.CommandTestMixin, unittest.TestCase):
 
         self.bot = FakeBot(self.basedir, False)
         self.bot.startService()
+        self.addCleanup(self.bot.stopService)
 
         # get a WorkerForBuilder object from the bot and wrap it as a fake
         # remote
@@ -222,12 +221,7 @@ class TestWorkerForBuilder(command.CommandTestMixin, unittest.TestCase):
 
         self.setUpCommand()
 
-    @defer.inlineCallbacks
     def tearDown(self):
-        self.tearDownCommand()
-
-        if self.bot and self.bot.running:
-            yield self.bot.stopService()
         if os.path.exists(self.basedir):
             shutil.rmtree(self.basedir)
 
@@ -356,7 +350,8 @@ class TestWorkerForBuilder(command.CommandTestMixin, unittest.TestCase):
         def do_start():
             return self.wfb.callRemote("startCommand", FakeRemote(st), "13", "shell", {})
 
-        yield self.assertFailure(do_start(), KeyError)
+        with self.assertRaises(KeyError):
+            yield do_start()
 
     @defer.inlineCallbacks
     def test_startCommand_invalid_command(self):
@@ -366,9 +361,11 @@ class TestWorkerForBuilder(command.CommandTestMixin, unittest.TestCase):
         def do_start():
             return self.wfb.callRemote("startCommand", FakeRemote(st), "13", "invalid command", {})
 
-        unknownCommand = yield self.assertFailure(do_start(), base.UnknownCommand)
+        with self.assertRaises(base.UnknownCommand) as e:
+            yield do_start()
         self.assertEqual(
-            str(unknownCommand), "(command 13): unrecognized WorkerCommand 'invalid command'"
+            e.exception.args,
+            ("(command 13): unrecognized WorkerCommand 'invalid command'",),
         )
 
 
@@ -397,7 +394,7 @@ class TestBotFactory(unittest.TestCase):
         self.bf.startTimers()
         clock.callLater(100, self.bf.stopTimers)
 
-        clock.pump((1 for _ in range(150)))
+        clock.pump(1 for _ in range(150))
         self.assertEqual(calls, [35, 70])
 
     def test_timers_exception(self):
