@@ -31,7 +31,7 @@ from buildbot_worker.test.util import misc
 try:
     from unittest.mock import Mock
 except ImportError:
-    from mock import Mock
+    from unittest.mock import Mock
 
 
 # I don't see any simple way to test the PB equipment without actually setting
@@ -52,7 +52,7 @@ class MasterPerspective(pb.Avatar):
 
 
 @implementer(portal.IRealm)
-class MasterRealm(object):
+class MasterRealm:
     def __init__(self, perspective, on_attachment):
         self.perspective = perspective
         self.on_attachment = on_attachment
@@ -65,7 +65,7 @@ class MasterRealm(object):
         if self.on_attachment:
             yield self.on_attachment(mind)
 
-        defer.returnValue((pb.IPerspective, self.perspective, lambda: None))
+        return pb.IPerspective, self.perspective, lambda: None
 
     def shutdown(self):
         return self.mind.broker.transport.loseConnection()
@@ -86,8 +86,6 @@ class TestWorker(misc.PatcherMixin, unittest.TestCase):
     def tearDown(self):
         if self.realm:
             yield self.realm.shutdown()
-        if self.worker and self.worker.running:
-            yield self.worker.stopService()
         if self.listeningport:
             yield self.listeningport.stopListening()
         if os.path.exists(self.basedir):
@@ -209,6 +207,7 @@ class TestWorker(misc.PatcherMixin, unittest.TestCase):
             protocol='pb',
         )
         self.worker.startService()
+        self.addCleanup(self.worker.stopService)
 
         # and wait for the result of the print
         return d
@@ -290,6 +289,7 @@ class TestWorker(misc.PatcherMixin, unittest.TestCase):
         )
 
         self.worker.startService()
+        self.addCleanup(self.worker.stopService)
 
         def check(ign):
             self.assertEqual(called, [('shutdown',)])
