@@ -12,6 +12,7 @@
 # Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # Copyright Buildbot Team Members
+from __future__ import annotations
 
 import os
 import shutil
@@ -24,11 +25,11 @@ from buildbot_worker.commands import utils
 
 
 class GetCommand(unittest.TestCase):
-    def setUp(self):
+    def setUp(self) -> None:
         # monkey-patch 'which' to return something appropriate
-        self.which_results = {}
+        self.which_results: dict[str, list[str]] = {}
 
-        def which(arg):
+        def which(arg: str) -> list[str]:
             return self.which_results.get(arg, [])
 
         self.patch(twisted.python.procutils, 'which', which)
@@ -36,29 +37,29 @@ class GetCommand(unittest.TestCase):
         # patch it there, too
         self.patch(utils, 'which', which)
 
-    def set_which_results(self, results):
+    def set_which_results(self, results: dict[str, list[str]]) -> None:
         self.which_results = results
 
-    def test_getCommand_empty(self):
+    def test_getCommand_empty(self) -> None:
         self.set_which_results({
             'xeyes': [],
         })
         with self.assertRaises(RuntimeError):
             utils.getCommand('xeyes')
 
-    def test_getCommand_single(self):
+    def test_getCommand_single(self) -> None:
         self.set_which_results({
             'xeyes': ['/usr/bin/xeyes'],
         })
         self.assertEqual(utils.getCommand('xeyes'), '/usr/bin/xeyes')
 
-    def test_getCommand_multi(self):
+    def test_getCommand_multi(self) -> None:
         self.set_which_results({
             'xeyes': ['/usr/bin/xeyes', '/usr/X11/bin/xeyes'],
         })
         self.assertEqual(utils.getCommand('xeyes'), '/usr/bin/xeyes')
 
-    def test_getCommand_single_exe(self):
+    def test_getCommand_single_exe(self) -> None:
         self.set_which_results({
             'xeyes': ['/usr/bin/xeyes'],
             # it should not select this option, since only one matched
@@ -67,7 +68,7 @@ class GetCommand(unittest.TestCase):
         })
         self.assertEqual(utils.getCommand('xeyes'), '/usr/bin/xeyes')
 
-    def test_getCommand_multi_exe(self):
+    def test_getCommand_multi_exe(self) -> None:
         self.set_which_results({
             'xeyes': [r'c:\program files\xeyes.com', r'c:\program files\xeyes.exe'],
             'xeyes.exe': [r'c:\program files\xeyes.exe'],
@@ -83,7 +84,7 @@ class RmdirRecursive(unittest.TestCase):
     # this is more complicated than you'd think because Twisted doesn't
     # rmdir its test directory very well, either..
 
-    def setUp(self):
+    def setUp(self) -> None:
         self.target = 'testdir'
         try:
             if os.path.exists(self.target):
@@ -103,7 +104,7 @@ class RmdirRecursive(unittest.TestCase):
         with open(os.path.join(self.target, "d", "d", "a"), "w"):
             pass
 
-    def tearDown(self):
+    def tearDown(self) -> None:
         try:
             if os.path.exists(self.target):
                 shutil.rmtree(self.target)
@@ -111,11 +112,11 @@ class RmdirRecursive(unittest.TestCase):
             print("\n(target directory was not removed by test, and cleanup failed too)\n")
             raise
 
-    def test_rmdirRecursive_easy(self):
+    def test_rmdirRecursive_easy(self) -> None:
         utils.rmdirRecursive(self.target)
         self.assertFalse(os.path.exists(self.target))
 
-    def test_rmdirRecursive_symlink(self):
+    def test_rmdirRecursive_symlink(self) -> None:
         # this was intended as a regression test for #792, but doesn't seem
         # to trigger it.  It can't hurt to check it, all the same.
         if runtime.platformType == 'win32':
