@@ -19,16 +19,19 @@ try:
     from buildbot_pkg import setup_www_plugin
 except ImportError:
     import sys
-    print('Please install buildbot_pkg module in order to install that '
-          'package, or use the pre-build .whl modules available on pypi',
-          file=sys.stderr)
+
+    print(
+        'Please install buildbot_pkg module in order to install that '
+        'package, or use the pre-build .whl modules available on pypi',
+        file=sys.stderr,
+    )
     sys.exit(1)
 
 setup_www_plugin(
     name='buildbot-www',
     description='Buildbot UI',
-    author=u'Pierre Tardy',
-    author_email=u'tardyp@gmail.com',
+    author='Povilas Kanapickas',
+    author_email='povilas@radix.lt',
     setup_requires=['buildbot_pkg'],
     install_requires=['buildbot'],
     url='http://buildbot.net/',
@@ -37,15 +40,12 @@ setup_www_plugin(
         '': [
             'VERSION',
             'static/*',
-            'static/img/*',
-            'static/fonts/*',
+            'static/assets/*',
         ]
     },
     entry_points="""
         [buildbot.www]
         base = buildbot_www:ep
     """,
-    classifiers=[
-        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)'
-    ],
+    classifiers=['License :: OSI Approved :: GNU General Public License v2 (GPLv2)'],
 )
