@@ -1,12 +1,14 @@
 import {resolve} from "path";
 import {defineConfig} from "vite";
 import dts from 'vite-plugin-dts'
+import checker from 'vite-plugin-checker';
 
 const outDir = 'dist';
 
 export default defineConfig({
   plugins: [
     dts(),
+    checker({typescript: true}),
   ],
   build: {
     lib: {
