@@ -18,11 +18,13 @@
 import axios, {AxiosRequestConfig} from 'axios';
 import {createElement, useEffect, useRef, useState} from "react";
 import * as fa from "react-icons/fa";
+import {IconType} from "react-icons";
 import {CancellablePromise, capitalize} from "buildbot-data-js";
 import {LoadingIndicator} from "buildbot-ui";
 import {buildbotSetupPlugin} from "buildbot-plugin-support";
+import {FaExclamationCircle} from "react-icons/fa";
 
-function getWsgiUrl(location: Location, name) {
+function getWsgiUrl(location: Location, name: string) {
   let pathname = location.pathname;
   if (!pathname.endsWith("/")) {
     pathname += "/";
@@ -30,7 +32,7 @@ function getWsgiUrl(location: Location, name) {
   return `${location.protocol}//${location.hostname}:${location.port}${pathname}plugins/wsgi_dashboards/${name}/index.html`;
 }
 
-function getData(url) {
+function getData(url: string) {
   return new CancellablePromise<any>((resolve, reject, onCancel) => {
     const controller = new AbortController();
     onCancel(() => {
@@ -51,7 +53,11 @@ function getData(url) {
   });
 }
 
-export default function WSGIDashboardsView({ name }) {
+export type WSGIDashboardsViewProps = {
+  name: string;
+}
+
+export default function WSGIDashboardsView({name}: WSGIDashboardsViewProps) {
   const location = getWsgiUrl(window.location, name);
   const pendingRequest = useRef<CancellablePromise<any> | null>(null);
 
@@ -85,6 +91,17 @@ export default function WSGIDashboardsView({ name }) {
   )
 }
 
+function getIcon(iconNames: string[]) : IconType|undefined {
+  for (const iconName in iconNames) {
+    // @ts-ignore
+    const icon = fa[iconName];
+    if (icon !== undefined) {
+      return icon;
+    }
+  }
+  return undefined
+}
+
 buildbotSetupPlugin((reg, config) => {
   const wsgi_dashboards = config.plugins['wsgi_dashboards'];
 
@@ -94,7 +111,16 @@ buildbotSetupPlugin((reg, config) => {
     if (caption == null) { caption = capitalize(name); }
     if (dashboard.order == null) { dashboard.order = 5; }
 
-    const icon = fa['Fa' + capitalize(dashboard.icon)];
+    const iconNames = [
+      'Fa' + capitalize(dashboard.icon),
+      String(dashboard.icon),
+    ];
+
+    let icon = getIcon(iconNames);
+    if (icon === undefined) {
+      icon = FaExclamationCircle;
+      console.log(`Error in WSGI plugin ${name}: Could not find icon ${dashboard.icon}`);
+    }
 
     reg.registerMenuGroup({
       name: name,
